﻿using System;
using System.Collections.Generic;
using System.Linq;
using Michigan.Ods.Sdk.Helpers;
using Michigan.Ods.Sdk.Models;
using RestSharp;
  using System.Net;
  using System.Text;
  
namespace Michigan.Ods.Sdk.Api 
{
    public class CohortsApi 
    {
        private readonly IRestClient client;

        public CohortsApi(IRestClient client)
        {
            this.client = client;
        }
      
        /// <summary>
        /// Retrieves resources based with paging capabilities (using the &quot;Get All&quot; pattern). This GET operation provides access to resources using the &quot;Get All&quot; pattern. In this version of the API there is support for paging.
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<Cohort>> GetCohortsAll(int? offset= null, int? limit= null) 
        {
            var request = new RestRequest("/cohorts", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            var response = client.Execute<List<Cohort>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves resources matching values of an example resource (using the &quot;Get By Example&quot; pattern). This GET operation provides access to resources using the &quot;Get by Example&quot; search pattern.  The values of any properties of the resource that are specified will be used to return all matching results (if it exists).
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <param name="identifier">The name or ID for the cohort.</param>
        /// <param name="educationOrganizationId">The identifier assigned to an education agency by the State Education Agency (SEA).  Also known as the State LEA ID.</param>
        /// <param name="description">The description of the Cohort and its purpose.</param>
        /// <param name="type">The type of cohort (e.g., academic intervention, classroom breakout).</param>
        /// <param name="scopeType">The scope of cohort (e.g., school, district, classroom).</param>
        /// <param name="academicSubjectDescriptor">The academic subject associated with an academic intervention.</param>
        /// <param name="id"></param>
        /// <param name="otherResearchCode1">(MI EXT) Field for use in researching or tracking student assessment information.</param>
        /// <param name="otherResearchCode2">(MI EXT) Field for use in researching or tracking student assessment information.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<Cohort>> GetCohortsAll(int? offset= null, int? limit= null, string identifier= null, int? educationOrganizationId= null, string description= null, string type= null, string scopeType= null, string academicSubjectDescriptor= null, string id= null, string otherResearchCode1= null, string otherResearchCode2= null) 
        {
            var request = new RestRequest("/cohorts", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            if (identifier != null)
                request.AddParameter("identifier", identifier);
            if (educationOrganizationId != null)
                request.AddParameter("educationOrganizationId", educationOrganizationId);
            if (description != null)
                request.AddParameter("description", description);
            if (type != null)
                request.AddParameter("type", type);
            if (scopeType != null)
                request.AddParameter("scopeType", scopeType);
            if (academicSubjectDescriptor != null)
                request.AddParameter("academicSubjectDescriptor", academicSubjectDescriptor);
            if (id != null)
                request.AddParameter("id", id);
            if (otherResearchCode1 != null)
                request.AddParameter("otherResearchCode1", otherResearchCode1);
            if (otherResearchCode2 != null)
                request.AddParameter("otherResearchCode2", otherResearchCode2);
            var response = client.Execute<List<Cohort>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the values of the resource's natural key (using the &quot;Get By Key&quot; pattern). This GET operation provides access to resources using the &quot;Get by Key&quot; search pattern. The values of the natural key of the resource must be fully specified, and the service will return the matching result (if it exists).
        /// </summary>
        /// <param name="identifier">The name or ID for the cohort.</param>
        /// <param name="educationOrganizationId">The identifier assigned to an education agency by the State Education Agency (SEA).  Also known as the State LEA ID.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<Cohort> GetCohortByKey(string identifier, int? educationOrganizationId, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/cohorts", Method.GET);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (identifier == null || educationOrganizationId == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            if (identifier != null)
                request.AddParameter("identifier", identifier);
            if (educationOrganizationId != null)
                request.AddParameter("educationOrganizationId", educationOrganizationId);
            request.AddHeader("If-None-Match", IfNoneMatch);
            var response = client.Execute<Cohort>(request);

            return response;
        }
        /// <summary>
        /// Creates or updates resources based on the natural key values of the supplied resource. The POST operation can be used to create or update resources. In database terms, this is often referred to as an &quot;upsert&quot; operation (insert + update).  Clients should NOT include the resource &quot;id&quot; in the JSON body because it will result in an error (you must use a PUT operation to update a resource by &quot;id&quot;). The web service will identify whether the resource already exists based on the natural key values provided, and update or create the resource appropriately.
        /// </summary>
        /// <param name="body">The JSON representation of the &quot;cohort&quot; resource to be created or updated.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse PostCohorts(Cohort body) 
        {
            var request = new RestRequest("/cohorts", Method.POST);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (body == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddBody(body);
            var response = client.Execute(request);

            var location = response.Headers.FirstOrDefault(x => x.Name == "Location");

            if (location != null && !string.IsNullOrWhiteSpace(location.Value.ToString()))
                body.id = location.Value.ToString().Split('/').Last();
            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the resource's identifier (using the &quot;Get By Id&quot; pattern). This GET operation retrieves a resource by the specified resource identifier.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be retrieved.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<Cohort> GetCohortsById(string id, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/cohorts/{id}", Method.GET);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-None-Match", IfNoneMatch);
            var response = client.Execute<Cohort>(request);

            return response;
        }
        /// <summary>
        /// Updates or creates a resource based on the resource identifier. The PUT operation is used to update or create a resource by identifier.  If the resource doesn't exist, the resource will be created using that identifier.  Additionally, natural key values cannot be changed using this operation, and will not be modified in the database.  If the resource &quot;id&quot; is provided in the JSON body, it will be ignored as well.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be updated.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the PUT from updating a resource modified by another consumer.</param>
        /// <param name="body">The JSON representation of the &quot;cohort&quot; resource to be updated.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse PutCohort(string id, string IfMatch, Cohort body) 
        {
            var request = new RestRequest("/cohorts/{id}", Method.PUT);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null || body == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            request.AddBody(body);
            var response = client.Execute(request);

            var location = response.Headers.FirstOrDefault(x => x.Name == "Location");

            if (location != null && !string.IsNullOrWhiteSpace(location.Value.ToString()))
                body.id = location.Value.ToString().Split('/').Last();
            return response;
        }
        /// <summary>
        /// Deletes an existing resource using the resource identifier. The DELETE operation is used to delete an existing resource by identifier.  If the resource doesn't exist, an error will result (the resource will not be found).
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be deleted.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the DELETE from removing a resource modified by another consumer.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse DeleteCohortById(string id, string IfMatch= null) 
        {
            var request = new RestRequest("/cohorts/{id}", Method.DELETE);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            var response = client.Execute(request);

            return response;
        }
        /// <summary>
        ///Retrieves a specific resource using the values of the resource's natural key (using the &quot;Get By Key&quot; pattern). This GET operation provides access to resources using the &quot;Get by Key&quot; search pattern. The values of the natural key of the resource must be fully specified, and the service will return the matching result (if it exists).
        ///</summary>
        /// <param name="identifier">The name or ID for the cohort.</param>
        /// <param name="educationOrganizationId">The identifier assigned to an education agency by the State Education Agency (SEA).  Also known as the State LEA ID.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        ///<returns></returns>
        public IRestResponse PatchGetCohortByKey(string identifier, int? educationOrganizationId, string IfNoneMatch, Cohort patchCohort)
        {
            // verify required params are set
            if (identifier == null || educationOrganizationId == null ) {
                throw new ArgumentException("API method call is missing required parameters");
            }
            var sdkUsageRecord = new SdkUsageRecord();
            var jsonSerializer = new RestSharp.Serializers.JsonSerializer();
            var statisticsTracker = new StatisticsTracker();

            var getResponse = this.GetCohortByKey( identifier, educationOrganizationId, IfNoneMatch);

            if (!(getResponse.StatusCode == HttpStatusCode.OK || getResponse.StatusCode == HttpStatusCode.Found))
                return getResponse;

            if (statisticsTracker.ShouldTrackStatistics)
            {
                sdkUsageRecord.DateTimeStamp = DateTime.Now;
                sdkUsageRecord.HttpMethod = "PatchGetCohortByKey";
                sdkUsageRecord.Url = "/cohorts";
                var serializedGetObject = jsonSerializer.Serialize(getResponse.Data);
                sdkUsageRecord.GetSizeInBytes = Encoding.UTF8.GetByteCount(serializedGetObject);
                var serializedPatchObject = jsonSerializer.Serialize(patchCohort);
                sdkUsageRecord.PatchSizeInBytes = Encoding.UTF8.GetByteCount(serializedPatchObject);
            }

            new PatchApplier().Execute(getResponse.Data, patchCohort);

            var putResponse = PutCohort( getResponse.Data.id, null, getResponse.Data ); 
            if (statisticsTracker.ShouldTrackStatistics)
            {
                var serializedPutObject = jsonSerializer.Serialize(getResponse.Data);
                sdkUsageRecord.PutSizeInBytes = Encoding.UTF8.GetByteCount(serializedPutObject);
                statisticsTracker.TrackIfEnabled(sdkUsageRecord);
            }
            return putResponse;
        }
        /// <summary>
        ///Retrieves a specific resource using the resource's identifier (using the &quot;Get By Id&quot; pattern). This GET operation retrieves a resource by the specified resource identifier.
        ///</summary>
        /// <param name="id">A resource identifier specifying the resource to be retrieved.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        ///<returns></returns>
        public IRestResponse PatchGetCohortsById(string id, string IfNoneMatch, Cohort patchCohort)
        {
            // verify required params are set
            if (id == null ) {
                throw new ArgumentException("API method call is missing required parameters");
            }
            var sdkUsageRecord = new SdkUsageRecord();
            var jsonSerializer = new RestSharp.Serializers.JsonSerializer();
            var statisticsTracker = new StatisticsTracker();

            var getResponse = this.GetCohortsById( id, IfNoneMatch);

            if (!(getResponse.StatusCode == HttpStatusCode.OK || getResponse.StatusCode == HttpStatusCode.Found))
                return getResponse;

            if (statisticsTracker.ShouldTrackStatistics)
            {
                sdkUsageRecord.DateTimeStamp = DateTime.Now;
                sdkUsageRecord.HttpMethod = "PatchGetCohortsById";
                sdkUsageRecord.Url = "/cohorts/{id}";
                var serializedGetObject = jsonSerializer.Serialize(getResponse.Data);
                sdkUsageRecord.GetSizeInBytes = Encoding.UTF8.GetByteCount(serializedGetObject);
                var serializedPatchObject = jsonSerializer.Serialize(patchCohort);
                sdkUsageRecord.PatchSizeInBytes = Encoding.UTF8.GetByteCount(serializedPatchObject);
            }

            new PatchApplier().Execute(getResponse.Data, patchCohort);

            var putResponse = PutCohort( getResponse.Data.id, null, getResponse.Data ); 
            if (statisticsTracker.ShouldTrackStatistics)
            {
                var serializedPutObject = jsonSerializer.Serialize(getResponse.Data);
                sdkUsageRecord.PutSizeInBytes = Encoding.UTF8.GetByteCount(serializedPutObject);
                statisticsTracker.TrackIfEnabled(sdkUsageRecord);
            }
            return putResponse;
        }
        }
}

