﻿using System;
using System.Collections.Generic;
using System.Linq;
using Michigan.Ods.Sdk.Helpers;
using Michigan.Ods.Sdk.Models;
using RestSharp;
  using System.Net;
  using System.Text;
  
namespace Michigan.Ods.Sdk.Api 
{
    public class InterventionPrescriptionsApi 
    {
        private readonly IRestClient client;

        public InterventionPrescriptionsApi(IRestClient client)
        {
            this.client = client;
        }
      
        /// <summary>
        /// Retrieves resources based with paging capabilities (using the &quot;Get All&quot; pattern). This GET operation provides access to resources using the &quot;Get All&quot; pattern. In this version of the API there is support for paging.
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<InterventionPrescription>> GetInterventionPrescriptionsAll(int? offset= null, int? limit= null) 
        {
            var request = new RestRequest("/interventionPrescriptions", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            var response = client.Execute<List<InterventionPrescription>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves resources matching values of an example resource (using the &quot;Get By Example&quot; pattern). This GET operation provides access to resources using the &quot;Get by Example&quot; search pattern.  The values of any properties of the resource that are specified will be used to return all matching results (if it exists).
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <param name="identificationCode">A unique number or alphanumeric code assigned to an intervention prescription.</param>
        /// <param name="educationOrganizationId">The identifier assigned to an education agency by the State Education Agency (SEA).  Also known as the State LEA ID.</param>
        /// <param name="interventionClassType">The way in which an intervention is used: curriculum, supplement, or practice.</param>
        /// <param name="id"></param>
        /// <param name="contactName">(MI EXT) Name of the Contact for this InterventionPrescription.</param>
        /// <param name="contactTelephoneNumber">(MI EXT) Telephone number of the Contact for this InterventionPrescription.</param>
        /// <param name="contactElectronicMailAddress">(MI EXT) Electronic mail (e-mail) of the Contact for this InterventionPrescription.</param>
        /// <param name="hasCost">0=No  1=Yes  NULL=Unknown</param>
        /// <param name="costStatement">(MI EXT) A statement that provides information regarding the cost of this InterventionPrescription.</param>
        /// <param name="deleted">(MI EXT) Indicates this InterventionPrescription has been deleted.  0=No  1=Yes  NULL=Unknown</param>
        /// <param name="description">(MI EXT) A description of this InterventionPrescription.</param>
        /// <param name="hasDuration">(MI EXT) 0=No  1=Yes  NULL=Unknown</param>
        /// <param name="durationLength">(MI EXT) Duration of length.</param>
        /// <param name="durationPeriod">(MI EXT) Duration of period.</param>
        /// <param name="hasEligibility">(MI EXT) 0=No  1=Yes  NULL=Unknown</param>
        /// <param name="eligibilityStatement">(MI EXT) A statement that provides information regarding the eligibility of this Intervention.</param>
        /// <param name="locationReferral">(MI EXT) 0 = No  1 = Yes  NULL = Unknown</param>
        /// <param name="parentPermissionRequired">(MI EXT) 0 = No  1 = Yes  NULL = Unknown</param>
        /// <param name="periodType">(MI EXT) Type of the period.</param>
        /// <param name="name">(MI EXT) The name of this InterventionPrescription.</param>
        /// <param name="originatingSourceDescriptor">(MI EXT) Indicates the source where Intervention or InterventionPrescription originated.</param>
        /// <param name="vettedByPET">(MI EXT) 0 = No  1 = Yes</param>
        /// <param name="tierDescriptor">(MI EXT) Indicates the tier.</param>
        /// <param name="organizationalSupportDescriptor">(MI EXT) Indicates the organizational support.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<InterventionPrescription>> GetInterventionPrescriptionsAll(int? offset= null, int? limit= null, string identificationCode= null, int? educationOrganizationId= null, string interventionClassType= null, string id= null, string contactName= null, string contactTelephoneNumber= null, string contactElectronicMailAddress= null, bool? hasCost= null, string costStatement= null, bool? deleted= null, string description= null, bool? hasDuration= null, int? durationLength= null, string durationPeriod= null, bool? hasEligibility= null, string eligibilityStatement= null, bool? locationReferral= null, bool? parentPermissionRequired= null, string periodType= null, string name= null, string originatingSourceDescriptor= null, bool? vettedByPET= null, string tierDescriptor= null, string organizationalSupportDescriptor= null) 
        {
            var request = new RestRequest("/interventionPrescriptions", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            if (identificationCode != null)
                request.AddParameter("identificationCode", identificationCode);
            if (educationOrganizationId != null)
                request.AddParameter("educationOrganizationId", educationOrganizationId);
            if (interventionClassType != null)
                request.AddParameter("interventionClassType", interventionClassType);
            if (id != null)
                request.AddParameter("id", id);
            if (contactName != null)
                request.AddParameter("contactName", contactName);
            if (contactTelephoneNumber != null)
                request.AddParameter("contactTelephoneNumber", contactTelephoneNumber);
            if (contactElectronicMailAddress != null)
                request.AddParameter("contactElectronicMailAddress", contactElectronicMailAddress);
            if (hasCost != null)
                request.AddParameter("hasCost", hasCost);
            if (costStatement != null)
                request.AddParameter("costStatement", costStatement);
            if (deleted != null)
                request.AddParameter("deleted", deleted);
            if (description != null)
                request.AddParameter("description", description);
            if (hasDuration != null)
                request.AddParameter("hasDuration", hasDuration);
            if (durationLength != null)
                request.AddParameter("durationLength", durationLength);
            if (durationPeriod != null)
                request.AddParameter("durationPeriod", durationPeriod);
            if (hasEligibility != null)
                request.AddParameter("hasEligibility", hasEligibility);
            if (eligibilityStatement != null)
                request.AddParameter("eligibilityStatement", eligibilityStatement);
            if (locationReferral != null)
                request.AddParameter("locationReferral", locationReferral);
            if (parentPermissionRequired != null)
                request.AddParameter("parentPermissionRequired", parentPermissionRequired);
            if (periodType != null)
                request.AddParameter("periodType", periodType);
            if (name != null)
                request.AddParameter("name", name);
            if (originatingSourceDescriptor != null)
                request.AddParameter("originatingSourceDescriptor", originatingSourceDescriptor);
            if (vettedByPET != null)
                request.AddParameter("vettedByPET", vettedByPET);
            if (tierDescriptor != null)
                request.AddParameter("tierDescriptor", tierDescriptor);
            if (organizationalSupportDescriptor != null)
                request.AddParameter("organizationalSupportDescriptor", organizationalSupportDescriptor);
            var response = client.Execute<List<InterventionPrescription>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the values of the resource's natural key (using the &quot;Get By Key&quot; pattern). This GET operation provides access to resources using the &quot;Get by Key&quot; search pattern. The values of the natural key of the resource must be fully specified, and the service will return the matching result (if it exists).
        /// </summary>
        /// <param name="identificationCode">A unique number or alphanumeric code assigned to an intervention prescription.</param>
        /// <param name="educationOrganizationId">The identifier assigned to an education agency by the State Education Agency (SEA).  Also known as the State LEA ID.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<InterventionPrescription> GetInterventionPrescriptionByKey(string identificationCode, int? educationOrganizationId, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/interventionPrescriptions", Method.GET);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (identificationCode == null || educationOrganizationId == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            if (identificationCode != null)
                request.AddParameter("identificationCode", identificationCode);
            if (educationOrganizationId != null)
                request.AddParameter("educationOrganizationId", educationOrganizationId);
            request.AddHeader("If-None-Match", IfNoneMatch);
            var response = client.Execute<InterventionPrescription>(request);

            return response;
        }
        /// <summary>
        /// Creates or updates resources based on the natural key values of the supplied resource. The POST operation can be used to create or update resources. In database terms, this is often referred to as an &quot;upsert&quot; operation (insert + update).  Clients should NOT include the resource &quot;id&quot; in the JSON body because it will result in an error (you must use a PUT operation to update a resource by &quot;id&quot;). The web service will identify whether the resource already exists based on the natural key values provided, and update or create the resource appropriately.
        /// </summary>
        /// <param name="body">The JSON representation of the &quot;interventionPrescription&quot; resource to be created or updated.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse PostInterventionPrescriptions(InterventionPrescription body) 
        {
            var request = new RestRequest("/interventionPrescriptions", Method.POST);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (body == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddBody(body);
            var response = client.Execute(request);

            var location = response.Headers.FirstOrDefault(x => x.Name == "Location");

            if (location != null && !string.IsNullOrWhiteSpace(location.Value.ToString()))
                body.id = location.Value.ToString().Split('/').Last();
            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the resource's identifier (using the &quot;Get By Id&quot; pattern). This GET operation retrieves a resource by the specified resource identifier.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be retrieved.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<InterventionPrescription> GetInterventionPrescriptionsById(string id, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/interventionPrescriptions/{id}", Method.GET);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-None-Match", IfNoneMatch);
            var response = client.Execute<InterventionPrescription>(request);

            return response;
        }
        /// <summary>
        /// Updates or creates a resource based on the resource identifier. The PUT operation is used to update or create a resource by identifier.  If the resource doesn't exist, the resource will be created using that identifier.  Additionally, natural key values cannot be changed using this operation, and will not be modified in the database.  If the resource &quot;id&quot; is provided in the JSON body, it will be ignored as well.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be updated.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the PUT from updating a resource modified by another consumer.</param>
        /// <param name="body">The JSON representation of the &quot;interventionPrescription&quot; resource to be updated.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse PutInterventionPrescription(string id, string IfMatch, InterventionPrescription body) 
        {
            var request = new RestRequest("/interventionPrescriptions/{id}", Method.PUT);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null || body == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            request.AddBody(body);
            var response = client.Execute(request);

            var location = response.Headers.FirstOrDefault(x => x.Name == "Location");

            if (location != null && !string.IsNullOrWhiteSpace(location.Value.ToString()))
                body.id = location.Value.ToString().Split('/').Last();
            return response;
        }
        /// <summary>
        /// Deletes an existing resource using the resource identifier. The DELETE operation is used to delete an existing resource by identifier.  If the resource doesn't exist, an error will result (the resource will not be found).
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be deleted.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the DELETE from removing a resource modified by another consumer.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse DeleteInterventionPrescriptionById(string id, string IfMatch= null) 
        {
            var request = new RestRequest("/interventionPrescriptions/{id}", Method.DELETE);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            var response = client.Execute(request);

            return response;
        }
        /// <summary>
        ///Retrieves a specific resource using the values of the resource's natural key (using the &quot;Get By Key&quot; pattern). This GET operation provides access to resources using the &quot;Get by Key&quot; search pattern. The values of the natural key of the resource must be fully specified, and the service will return the matching result (if it exists).
        ///</summary>
        /// <param name="identificationCode">A unique number or alphanumeric code assigned to an intervention prescription.</param>
        /// <param name="educationOrganizationId">The identifier assigned to an education agency by the State Education Agency (SEA).  Also known as the State LEA ID.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        ///<returns></returns>
        public IRestResponse PatchGetInterventionPrescriptionByKey(string identificationCode, int? educationOrganizationId, string IfNoneMatch, InterventionPrescription patchInterventionPrescription)
        {
            // verify required params are set
            if (identificationCode == null || educationOrganizationId == null ) {
                throw new ArgumentException("API method call is missing required parameters");
            }
            var sdkUsageRecord = new SdkUsageRecord();
            var jsonSerializer = new RestSharp.Serializers.JsonSerializer();
            var statisticsTracker = new StatisticsTracker();

            var getResponse = this.GetInterventionPrescriptionByKey( identificationCode, educationOrganizationId, IfNoneMatch);

            if (!(getResponse.StatusCode == HttpStatusCode.OK || getResponse.StatusCode == HttpStatusCode.Found))
                return getResponse;

            if (statisticsTracker.ShouldTrackStatistics)
            {
                sdkUsageRecord.DateTimeStamp = DateTime.Now;
                sdkUsageRecord.HttpMethod = "PatchGetInterventionPrescriptionByKey";
                sdkUsageRecord.Url = "/interventionPrescriptions";
                var serializedGetObject = jsonSerializer.Serialize(getResponse.Data);
                sdkUsageRecord.GetSizeInBytes = Encoding.UTF8.GetByteCount(serializedGetObject);
                var serializedPatchObject = jsonSerializer.Serialize(patchInterventionPrescription);
                sdkUsageRecord.PatchSizeInBytes = Encoding.UTF8.GetByteCount(serializedPatchObject);
            }

            new PatchApplier().Execute(getResponse.Data, patchInterventionPrescription);

            var putResponse = PutInterventionPrescription( getResponse.Data.id, null, getResponse.Data ); 
            if (statisticsTracker.ShouldTrackStatistics)
            {
                var serializedPutObject = jsonSerializer.Serialize(getResponse.Data);
                sdkUsageRecord.PutSizeInBytes = Encoding.UTF8.GetByteCount(serializedPutObject);
                statisticsTracker.TrackIfEnabled(sdkUsageRecord);
            }
            return putResponse;
        }
        /// <summary>
        ///Retrieves a specific resource using the resource's identifier (using the &quot;Get By Id&quot; pattern). This GET operation retrieves a resource by the specified resource identifier.
        ///</summary>
        /// <param name="id">A resource identifier specifying the resource to be retrieved.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        ///<returns></returns>
        public IRestResponse PatchGetInterventionPrescriptionsById(string id, string IfNoneMatch, InterventionPrescription patchInterventionPrescription)
        {
            // verify required params are set
            if (id == null ) {
                throw new ArgumentException("API method call is missing required parameters");
            }
            var sdkUsageRecord = new SdkUsageRecord();
            var jsonSerializer = new RestSharp.Serializers.JsonSerializer();
            var statisticsTracker = new StatisticsTracker();

            var getResponse = this.GetInterventionPrescriptionsById( id, IfNoneMatch);

            if (!(getResponse.StatusCode == HttpStatusCode.OK || getResponse.StatusCode == HttpStatusCode.Found))
                return getResponse;

            if (statisticsTracker.ShouldTrackStatistics)
            {
                sdkUsageRecord.DateTimeStamp = DateTime.Now;
                sdkUsageRecord.HttpMethod = "PatchGetInterventionPrescriptionsById";
                sdkUsageRecord.Url = "/interventionPrescriptions/{id}";
                var serializedGetObject = jsonSerializer.Serialize(getResponse.Data);
                sdkUsageRecord.GetSizeInBytes = Encoding.UTF8.GetByteCount(serializedGetObject);
                var serializedPatchObject = jsonSerializer.Serialize(patchInterventionPrescription);
                sdkUsageRecord.PatchSizeInBytes = Encoding.UTF8.GetByteCount(serializedPatchObject);
            }

            new PatchApplier().Execute(getResponse.Data, patchInterventionPrescription);

            var putResponse = PutInterventionPrescription( getResponse.Data.id, null, getResponse.Data ); 
            if (statisticsTracker.ShouldTrackStatistics)
            {
                var serializedPutObject = jsonSerializer.Serialize(getResponse.Data);
                sdkUsageRecord.PutSizeInBytes = Encoding.UTF8.GetByteCount(serializedPutObject);
                statisticsTracker.TrackIfEnabled(sdkUsageRecord);
            }
            return putResponse;
        }
        }
}

