﻿using System;
using System.Collections.Generic;
using System.Linq;
using Michigan.Ods.Sdk.Helpers;
using Michigan.Ods.Sdk.Models;
using RestSharp;
  using System.Net;
  using System.Text;
  
namespace Michigan.Ods.Sdk.Api 
{
    public class ReportCardsApi 
    {
        private readonly IRestClient client;

        public ReportCardsApi(IRestClient client)
        {
            this.client = client;
        }
      
        /// <summary>
        /// Retrieves resources based with paging capabilities (using the &quot;Get All&quot; pattern). This GET operation provides access to resources using the &quot;Get All&quot; pattern. In this version of the API there is support for paging.
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<ReportCard>> GetReportCardsAll(int? offset= null, int? limit= null) 
        {
            var request = new RestRequest("/reportCards", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            var response = client.Execute<List<ReportCard>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves resources matching values of an example resource (using the &quot;Get By Example&quot; pattern). This GET operation provides access to resources using the &quot;Get by Example&quot; search pattern.  The values of any properties of the resource that are specified will be used to return all matching results (if it exists).
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <param name="studentUniqueId">A unique alpha-numeric code assigned to a student.</param>
        /// <param name="educationOrganizationId">The identifier assigned to an education agency by the State Education Agency (SEA).  Also known as the State LEA ID.</param>
        /// <param name="gradingPeriodDescriptor">The name of the period for which grades are reported.</param>
        /// <param name="gradingPeriodBeginDate">Month, day, and year of the first day of the GradingPeriod.</param>
        /// <param name="schoolId">The identifier assigned to a school by the State Education Agency (SEA).</param>
        /// <param name="gpaGivenGradingPeriod">A measure of average performance in all courses taken by an individual for the current grading period.</param>
        /// <param name="gpaCumulative">A measure of cumulative average performance in all courses taken by an individual from the beginning of the school year through the current grading period.</param>
        /// <param name="numberOfDaysAbsent">The number of days an individual is absent when school is in session during a given reporting period.</param>
        /// <param name="numberOfDaysInAttendance">The number of days an individual is present when school is in session during a given reporting period.</param>
        /// <param name="numberOfDaysTardy">The number of days an individual is tardy during a given reporting period.</param>
        /// <param name="id"></param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<ReportCard>> GetReportCardsAll(int? offset= null, int? limit= null, string studentUniqueId= null, int? educationOrganizationId= null, string gradingPeriodDescriptor= null, DateTime? gradingPeriodBeginDate= null, int? schoolId= null, double? gpaGivenGradingPeriod= null, double? gpaCumulative= null, double? numberOfDaysAbsent= null, double? numberOfDaysInAttendance= null, int? numberOfDaysTardy= null, string id= null) 
        {
            var request = new RestRequest("/reportCards", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            if (studentUniqueId != null)
                request.AddParameter("studentUniqueId", studentUniqueId);
            if (educationOrganizationId != null)
                request.AddParameter("educationOrganizationId", educationOrganizationId);
            if (gradingPeriodDescriptor != null)
                request.AddParameter("gradingPeriodDescriptor", gradingPeriodDescriptor);
            if (gradingPeriodBeginDate != null)
                request.AddParameter("gradingPeriodBeginDate", gradingPeriodBeginDate);
            if (schoolId != null)
                request.AddParameter("schoolId", schoolId);
            if (gpaGivenGradingPeriod != null)
                request.AddParameter("gpaGivenGradingPeriod", gpaGivenGradingPeriod);
            if (gpaCumulative != null)
                request.AddParameter("gpaCumulative", gpaCumulative);
            if (numberOfDaysAbsent != null)
                request.AddParameter("numberOfDaysAbsent", numberOfDaysAbsent);
            if (numberOfDaysInAttendance != null)
                request.AddParameter("numberOfDaysInAttendance", numberOfDaysInAttendance);
            if (numberOfDaysTardy != null)
                request.AddParameter("numberOfDaysTardy", numberOfDaysTardy);
            if (id != null)
                request.AddParameter("id", id);
            var response = client.Execute<List<ReportCard>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the values of the resource's natural key (using the &quot;Get By Key&quot; pattern). This GET operation provides access to resources using the &quot;Get by Key&quot; search pattern. The values of the natural key of the resource must be fully specified, and the service will return the matching result (if it exists).
        /// </summary>
        /// <param name="studentUniqueId">A unique alpha-numeric code assigned to a student.</param>
        /// <param name="educationOrganizationId">The identifier assigned to an education agency by the State Education Agency (SEA).  Also known as the State LEA ID.</param>
        /// <param name="gradingPeriodDescriptor">The name of the period for which grades are reported.</param>
        /// <param name="gradingPeriodBeginDate">Month, day, and year of the first day of the GradingPeriod.</param>
        /// <param name="schoolId">The identifier assigned to a school by the State Education Agency (SEA).</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<ReportCard> GetReportCardByKey(string studentUniqueId, int? educationOrganizationId, string gradingPeriodDescriptor, DateTime? gradingPeriodBeginDate, int? schoolId, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/reportCards", Method.GET);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (studentUniqueId == null || educationOrganizationId == null || gradingPeriodDescriptor == null || gradingPeriodBeginDate == null || schoolId == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            if (studentUniqueId != null)
                request.AddParameter("studentUniqueId", studentUniqueId);
            if (educationOrganizationId != null)
                request.AddParameter("educationOrganizationId", educationOrganizationId);
            if (gradingPeriodDescriptor != null)
                request.AddParameter("gradingPeriodDescriptor", gradingPeriodDescriptor);
            if (gradingPeriodBeginDate != null)
                request.AddParameter("gradingPeriodBeginDate", gradingPeriodBeginDate);
            if (schoolId != null)
                request.AddParameter("schoolId", schoolId);
            request.AddHeader("If-None-Match", IfNoneMatch);
            var response = client.Execute<ReportCard>(request);

            return response;
        }
        /// <summary>
        /// Creates or updates resources based on the natural key values of the supplied resource. The POST operation can be used to create or update resources. In database terms, this is often referred to as an &quot;upsert&quot; operation (insert + update).  Clients should NOT include the resource &quot;id&quot; in the JSON body because it will result in an error (you must use a PUT operation to update a resource by &quot;id&quot;). The web service will identify whether the resource already exists based on the natural key values provided, and update or create the resource appropriately.
        /// </summary>
        /// <param name="body">The JSON representation of the &quot;reportCard&quot; resource to be created or updated.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse PostReportCards(ReportCard body) 
        {
            var request = new RestRequest("/reportCards", Method.POST);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (body == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddBody(body);
            var response = client.Execute(request);

            var location = response.Headers.FirstOrDefault(x => x.Name == "Location");

            if (location != null && !string.IsNullOrWhiteSpace(location.Value.ToString()))
                body.id = location.Value.ToString().Split('/').Last();
            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the resource's identifier (using the &quot;Get By Id&quot; pattern). This GET operation retrieves a resource by the specified resource identifier.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be retrieved.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<ReportCard> GetReportCardsById(string id, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/reportCards/{id}", Method.GET);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-None-Match", IfNoneMatch);
            var response = client.Execute<ReportCard>(request);

            return response;
        }
        /// <summary>
        /// Updates or creates a resource based on the resource identifier. The PUT operation is used to update or create a resource by identifier.  If the resource doesn't exist, the resource will be created using that identifier.  Additionally, natural key values cannot be changed using this operation, and will not be modified in the database.  If the resource &quot;id&quot; is provided in the JSON body, it will be ignored as well.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be updated.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the PUT from updating a resource modified by another consumer.</param>
        /// <param name="body">The JSON representation of the &quot;reportCard&quot; resource to be updated.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse PutReportCard(string id, string IfMatch, ReportCard body) 
        {
            var request = new RestRequest("/reportCards/{id}", Method.PUT);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null || body == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            request.AddBody(body);
            var response = client.Execute(request);

            var location = response.Headers.FirstOrDefault(x => x.Name == "Location");

            if (location != null && !string.IsNullOrWhiteSpace(location.Value.ToString()))
                body.id = location.Value.ToString().Split('/').Last();
            return response;
        }
        /// <summary>
        /// Deletes an existing resource using the resource identifier. The DELETE operation is used to delete an existing resource by identifier.  If the resource doesn't exist, an error will result (the resource will not be found).
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be deleted.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the DELETE from removing a resource modified by another consumer.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse DeleteReportCardById(string id, string IfMatch= null) 
        {
            var request = new RestRequest("/reportCards/{id}", Method.DELETE);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            var response = client.Execute(request);

            return response;
        }
        /// <summary>
        ///Retrieves a specific resource using the values of the resource's natural key (using the &quot;Get By Key&quot; pattern). This GET operation provides access to resources using the &quot;Get by Key&quot; search pattern. The values of the natural key of the resource must be fully specified, and the service will return the matching result (if it exists).
        ///</summary>
        /// <param name="studentUniqueId">A unique alpha-numeric code assigned to a student.</param>
        /// <param name="educationOrganizationId">The identifier assigned to an education agency by the State Education Agency (SEA).  Also known as the State LEA ID.</param>
        /// <param name="gradingPeriodDescriptor">The name of the period for which grades are reported.</param>
        /// <param name="gradingPeriodBeginDate">Month, day, and year of the first day of the GradingPeriod.</param>
        /// <param name="schoolId">The identifier assigned to a school by the State Education Agency (SEA).</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        ///<returns></returns>
        public IRestResponse PatchGetReportCardByKey(string studentUniqueId, int? educationOrganizationId, string gradingPeriodDescriptor, DateTime? gradingPeriodBeginDate, int? schoolId, string IfNoneMatch, ReportCard patchReportCard)
        {
            // verify required params are set
            if (studentUniqueId == null || educationOrganizationId == null || gradingPeriodDescriptor == null || gradingPeriodBeginDate == null || schoolId == null ) {
                throw new ArgumentException("API method call is missing required parameters");
            }
            var sdkUsageRecord = new SdkUsageRecord();
            var jsonSerializer = new RestSharp.Serializers.JsonSerializer();
            var statisticsTracker = new StatisticsTracker();

            var getResponse = this.GetReportCardByKey( studentUniqueId, educationOrganizationId, gradingPeriodDescriptor, gradingPeriodBeginDate, schoolId, IfNoneMatch);

            if (!(getResponse.StatusCode == HttpStatusCode.OK || getResponse.StatusCode == HttpStatusCode.Found))
                return getResponse;

            if (statisticsTracker.ShouldTrackStatistics)
            {
                sdkUsageRecord.DateTimeStamp = DateTime.Now;
                sdkUsageRecord.HttpMethod = "PatchGetReportCardByKey";
                sdkUsageRecord.Url = "/reportCards";
                var serializedGetObject = jsonSerializer.Serialize(getResponse.Data);
                sdkUsageRecord.GetSizeInBytes = Encoding.UTF8.GetByteCount(serializedGetObject);
                var serializedPatchObject = jsonSerializer.Serialize(patchReportCard);
                sdkUsageRecord.PatchSizeInBytes = Encoding.UTF8.GetByteCount(serializedPatchObject);
            }

            new PatchApplier().Execute(getResponse.Data, patchReportCard);

            var putResponse = PutReportCard( getResponse.Data.id, null, getResponse.Data ); 
            if (statisticsTracker.ShouldTrackStatistics)
            {
                var serializedPutObject = jsonSerializer.Serialize(getResponse.Data);
                sdkUsageRecord.PutSizeInBytes = Encoding.UTF8.GetByteCount(serializedPutObject);
                statisticsTracker.TrackIfEnabled(sdkUsageRecord);
            }
            return putResponse;
        }
        /// <summary>
        ///Retrieves a specific resource using the resource's identifier (using the &quot;Get By Id&quot; pattern). This GET operation retrieves a resource by the specified resource identifier.
        ///</summary>
        /// <param name="id">A resource identifier specifying the resource to be retrieved.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        ///<returns></returns>
        public IRestResponse PatchGetReportCardsById(string id, string IfNoneMatch, ReportCard patchReportCard)
        {
            // verify required params are set
            if (id == null ) {
                throw new ArgumentException("API method call is missing required parameters");
            }
            var sdkUsageRecord = new SdkUsageRecord();
            var jsonSerializer = new RestSharp.Serializers.JsonSerializer();
            var statisticsTracker = new StatisticsTracker();

            var getResponse = this.GetReportCardsById( id, IfNoneMatch);

            if (!(getResponse.StatusCode == HttpStatusCode.OK || getResponse.StatusCode == HttpStatusCode.Found))
                return getResponse;

            if (statisticsTracker.ShouldTrackStatistics)
            {
                sdkUsageRecord.DateTimeStamp = DateTime.Now;
                sdkUsageRecord.HttpMethod = "PatchGetReportCardsById";
                sdkUsageRecord.Url = "/reportCards/{id}";
                var serializedGetObject = jsonSerializer.Serialize(getResponse.Data);
                sdkUsageRecord.GetSizeInBytes = Encoding.UTF8.GetByteCount(serializedGetObject);
                var serializedPatchObject = jsonSerializer.Serialize(patchReportCard);
                sdkUsageRecord.PatchSizeInBytes = Encoding.UTF8.GetByteCount(serializedPatchObject);
            }

            new PatchApplier().Execute(getResponse.Data, patchReportCard);

            var putResponse = PutReportCard( getResponse.Data.id, null, getResponse.Data ); 
            if (statisticsTracker.ShouldTrackStatistics)
            {
                var serializedPutObject = jsonSerializer.Serialize(getResponse.Data);
                sdkUsageRecord.PutSizeInBytes = Encoding.UTF8.GetByteCount(serializedPutObject);
                statisticsTracker.TrackIfEnabled(sdkUsageRecord);
            }
            return putResponse;
        }
        }
}

