﻿using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace Michigan.Ods.Sdk.Models 
{
    public class CommunityProvider 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// A reference to the related CommunityOrganization resource.
        /// </summary>
        public CommunityOrganizationReference communityOrganizationReference { get; set; }

        /// <summary>
        /// The identifier assigned to a Community Provider.
        /// </summary>
        public int? communityProviderId { get; set; }

        /// <summary>
        /// The identifier assigned to an education organization by the StateEducationAgency (SEA).
        /// </summary>
        public string stateOrganizationId { get; set; }

        /// <summary>
        /// The full, legally accepted name of the institution.
        /// </summary>
        public string nameOfInstitution { get; set; }

        /// <summary>
        /// A short name for the institution.
        /// </summary>
        public string shortNameOfInstitution { get; set; }

        /// <summary>
        /// The public web site address (URL) for the EducationOrganization.
        /// </summary>
        public string webSite { get; set; }

        /// <summary>
        /// The current operational status of the EducationOrganization (e.g., active, inactive).
        /// </summary>
        public string operationalStatusType { get; set; }

        /// <summary>
        /// Indicates the type of community provider.
        /// </summary>
        public string providerTypeDescriptor { get; set; }

        /// <summary>
        /// Indicates the provider status.
        /// </summary>
        public string providerStatusDescriptor { get; set; }

        /// <summary>
        /// A indication whether or not this community provider is also a school.
        /// </summary>
        public bool? schoolFlag { get; set; }

        /// <summary>
        /// Indicates the provider profitability type.
        /// </summary>
        public string providerProfitabilityDescriptor { get; set; }

        /// <summary>
        /// An indication as to whether or not the provider is exempt from having a license.
        /// </summary>
        public bool? licenseExemptFlag { get; set; }

        /// <summary>
        /// An unordered collection of educationOrganizationAddresses.  The set of elements that describes the physical location of the education entity, including the street address, city, state, ZIP code, and ZIP code + 4.
        /// </summary>
        public List<EducationOrganizationAddress> addresses { get; set; }

        /// <summary>
        /// An unordered collection of educationOrganizationCategories.  The classification of the education agency within the geographic boundaries of a state according to the level of administrative and operational control granted by the state.
        /// </summary>
        public List<EducationOrganizationCategory> educationOrganizationCategories { get; set; }

        /// <summary>
        /// An unordered collection of educationOrganizationIdentificationCodes.  A unique number or alphanumeric code assigned to an education organization by a school, school system, a state, or other agency or entity.
        /// </summary>
        public List<EducationOrganizationIdentificationCode> identificationCodes { get; set; }

        /// <summary>
        /// An unordered collection of educationOrganizationInstitutionTelephones.  The 10-digit telephone number, including the area code, for the education entity.
        /// </summary>
        public List<EducationOrganizationInstitutionTelephone> institutionTelephones { get; set; }

        /// <summary>
        /// An unordered collection of educationOrganizationInternationalAddresses.  The set of elements that describes the international physical location of the education entity.
        /// </summary>
        public List<EducationOrganizationInternationalAddress> internationalAddresses { get; set; }

        /// <summary>
        /// An unordered collection of communityProviderLicenses.  Licensing information for the community provider.
        /// </summary>
        public List<CommunityProviderLicense> licenses { get; set; }

        /// <summary>
        /// An unordered collection of communityProviderQRISRatings.  A list of Quality Rating and Improvement System rating information over time for a community provider.
        /// </summary>
        public List<CommunityProviderQRISRating> qrisRatings { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

