﻿using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace Michigan.Ods.Sdk.Models 
{
    public class CommunityProviderLocation 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// A reference to the related CommunityProvider resource.
        /// </summary>
        public CommunityProviderReference communityProviderReference { get; set; }

        /// <summary>
        /// A unique number or alphanumeric code assigned to an education organization by a school, school system, a state, or other agency or entity.
        /// </summary>
        public int? communityProviderLocationId { get; set; }

        /// <summary>
        /// An indication of the range of ages of students that this provider location can accommodate.
        /// </summary>
        public string ageRangeDescription { get; set; }

        /// <summary>
        /// The youngest age of students accepted at this location.
        /// </summary>
        public int? youngestAgeAccepted { get; set; }

        /// <summary>
        /// The oldest age of students accepted at this location.
        /// </summary>
        public int? oldestAgeAccepted { get; set; }

        /// <summary>
        /// The maximum number of students this provider location can accommodate at any given time.
        /// </summary>
        public int? capacity { get; set; }

        /// <summary>
        /// An indication of whether a provider location serves children with special needs.
        /// </summary>
        public bool? specialNeedsProvidedFlag { get; set; }

        /// <summary>
        /// The time of day this provider location begins providing services.
        /// </summary>
        public string timeOpen { get; set; }

        /// <summary>
        /// The time of day this provider location stops providing services.
        /// </summary>
        public string timeClose { get; set; }

        /// <summary>
        /// The type of address listed for the community provider location.
        /// </summary>
        public string addressType { get; set; }

        /// <summary>
        /// The street number and street name or post office box number of an address.
        /// </summary>
        public string streetNumberName { get; set; }

        /// <summary>
        /// The street number and street name or post office box number of an address.
        /// </summary>
        public string apartmentRoomSuiteNumber { get; set; }

        /// <summary>
        /// The number of the building on the site, if more than one building shares the same address.
        /// </summary>
        public string buildingSiteNumber { get; set; }

        /// <summary>
        /// The name of the city in which an address is located.
        /// </summary>
        public string city { get; set; }

        /// <summary>
        /// The abbreviation for the state (within the United States) or outlying area in which an address is located.
        /// </summary>
        public string stateAbbreviationType { get; set; }

        /// <summary>
        /// The five or nine digit zip code or overseas postal code portion of an address.
        /// </summary>
        public string postalCode { get; set; }

        /// <summary>
        /// The name of the county, parish, borough, or comparable unit (within a state) in which an address is located.
        /// </summary>
        public string nameOfCounty { get; set; }

        /// <summary>
        /// The Federal Information Processing Standards (FIPS) numeric code for the county issued by the National Institute of Standards and Technology (NIST). Counties are considered to be the 'first-order subdivisions' of each State and statistically equivalent entity, regardless of their local designations (county, parish, borough, etc.). Counties in different States will have the same code. A unique county number is created when combined with the 2-digit FIPS State Code.
        /// </summary>
        public string countyFIPSCode { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

