﻿using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace Michigan.Ods.Sdk.Models 
{
    public class EemEducationalEntityMasterDetail 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// Educational Entity Master identifier from EEM system.
        /// </summary>
        public int? eemEducationalEntityMasterId { get; set; }

        /// <summary>
        /// NEED DESCRIPTION.
        /// </summary>
        public DateTime? effectiveDate { get; set; }

        /// <summary>
        /// NEED DESCRIPTION.
        /// </summary>
        public DateTime? expirationDate { get; set; }

        /// <summary>
        /// 1 = Is headcount; 0 or NULL = is not headcount;
        /// </summary>
        public bool? isHeadCount { get; set; }

        /// <summary>
        /// 1 = School of Choice is Offered; 0 or NULL = School of Choice is not Offered;
        /// </summary>
        public bool? isSchoolOfChoiceOffered { get; set; }

        /// <summary>
        /// 1 = is shared entity; 0 or NULL = is not shared entity;
        /// </summary>
        public bool? isSharedEntity { get; set; }

        /// <summary>
        /// Indicates the measure of an EEM School location relative to populous areas.
        /// </summary>
        public string eemLocaleDescriptor { get; set; }

        /// <summary>
        /// Denotes whether or not an Educational Entity is a magnet school.
        /// </summary>
        public string eemMagnetDescriptor { get; set; }

        /// <summary>
        /// Describes the type of Ownership of an Educational Entity.
        /// </summary>
        public string eemOwnershipDescriptor { get; set; }

        /// <summary>
        /// Reflects the list of organized groups of religious congregations.
        /// </summary>
        public string eemReligiousOrientationDescriptor { get; set; }

        /// <summary>
        /// Indicates the EEM Shared Educational Entity (SEE) participation type.
        /// </summary>
        public string eemseeTypeDescriptor { get; set; }

        /// <summary>
        /// Indicates the sub type of the EEM Shared Educational Entity (SEE) participation type.
        /// </summary>
        public string eemseeSubTypeDescriptor { get; set; }

        /// <summary>
        /// Indicates the Early Middle College type for which this Educational Entity has to allow a pupil to earn a high school diploma and an associate degree or up to two years of transferable college credits.
        /// </summary>
        public string eemEarlyMiddleCollegeTypeDescriptor { get; set; }

        /// <summary>
        /// Indicates the non-instructional functions designated by the EEM authorized user for this entity.
        /// </summary>
        public string eemAncillaryFunctionDescriptor { get; set; }

        /// <summary>
        /// The 9-digit agreement number assigned by the EEM system. Formerly referred to as the recipient code. Used by the Budget and Grants Office of the Michigan Department of Education.
        /// </summary>
        public string eemAgreementNumber { get; set; }

        /// <summary>
        /// EEM Regional Educational Media Center identifier.
        /// </summary>
        public string eemremcId { get; set; }

        /// <summary>
        /// Provided by MDE. The ten position code number of the agency that charters a Public School Academy.
        /// </summary>
        public string eemCharteringAgencyCode { get; set; }

        /// <summary>
        /// The EEM identifier of the agency that charters a Public School Academy.
        /// </summary>
        public int? eemCharteringAgencyEntityId { get; set; }

        /// <summary>
        /// Denotes the ACT Test Center of the Educational Entity.
        /// </summary>
        public string eemactTestCenter { get; set; }

        /// <summary>
        /// Denotes the SAT Test Center for the Educational Entity.
        /// </summary>
        public string eemsatTestCenter { get; set; }

        /// <summary>
        /// Denotes from where Educational Entity receives transportation services.
        /// </summary>
        public int? eemReceivesTransportationServicesFrom { get; set; }

        /// <summary>
        /// Denotes the EEM AYP attributes of the Educational Entity.
        /// </summary>
        public EemEducationalEntityMasterDetailEEMAYP eemayp { get; set; }

        /// <summary>
        /// Denotes the Title I attributes of the Educational Entity.
        /// </summary>
        public EemEducationalEntityMasterDetailEEMTitleI eemTitleI { get; set; }

        /// <summary>
        /// An unordered collection of eemEducationalEntityMasterDetailEEMCharacteristicGroups.  Additional characteristics of the EEM Educational Entity.
        /// </summary>
        public List<EemEducationalEntityMasterDetailEEMCharacteristicGroup> eemCharacteristicGroups { get; set; }

        /// <summary>
        /// An unordered collection of eemEducationalEntityMasterDetailEEMTitleIStatuses.  Denotes the Title I Status attributes of the Educational Entity.
        /// </summary>
        public List<EemEducationalEntityMasterDetailEEMTitleIStatus> eemTitleIStatuses { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

