﻿using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace Michigan.Ods.Sdk.Models 
{
    public class GraduationPlan 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// A reference to the related EducationOrganization resource.
        /// </summary>
        public EducationOrganizationReference educationOrganizationReference { get; set; }

        /// <summary>
        /// A reference to the related SchoolYearType resource.
        /// </summary>
        public SchoolYearTypeReference graduationSchoolYearTypeReference { get; set; }

        /// <summary>
        /// The type of academic plan the student is following for graduation: for example, Minimum, Recommended, Distinguished, or Standard.
        /// </summary>
        public string typeDescriptor { get; set; }

        /// <summary>
        /// An indicator of whether the GraduationPlan is tailored for an individual.
        /// </summary>
        public bool? individualPlan { get; set; }

        /// <summary>
        /// The value of credits or units of value awarded for the completion of a course.
        /// </summary>
        public double? totalRequiredCredits { get; set; }

        /// <summary>
        /// The type of credits or units of value awarded for the completion of a course.
        /// </summary>
        public string totalRequiredCreditType { get; set; }

        /// <summary>
        /// Conversion factor that when multiplied by the number of credits is equivalent to Carnegie units.
        /// </summary>
        public double? totalRequiredCreditConversion { get; set; }

        /// <summary>
        /// (MI EXT) The most recent date of changes to CreditModification.
        /// </summary>
        public DateTime? creditModificationAsOfDate { get; set; }

        /// <summary>
        /// (MI EXT) To indicate the criteria under which the students's curriculum modification is allowed.
        /// </summary>
        public string curriculumDescriptor { get; set; }

        /// <summary>
        /// An unordered collection of graduationPlanCreditModifications.  (MI EXT) To indicate the academic area that is being modified by the personal curriculum.
        /// </summary>
        public List<GraduationPlanCreditModification> creditModifications { get; set; }

        /// <summary>
        /// An unordered collection of graduationPlanCreditsByCourses.  The total credits required for graduation by taking a specific course, or by taking one or more from a set of courses.
        /// </summary>
        public List<GraduationPlanCreditsByCourse> creditsByCourses { get; set; }

        /// <summary>
        /// An unordered collection of graduationPlanCreditsBySubjects.  The total credits required in subject to graduate. Only those courses identified as a high school course requirement are eligible to meet subject credit requirements.
        /// </summary>
        public List<GraduationPlanCreditsBySubject> creditsBySubjects { get; set; }

        /// <summary>
        /// An unordered collection of graduationPlanRequiredAssessments.  The assessments and associated required score and performance level needed to satisfy graduation requirements.
        /// </summary>
        public List<GraduationPlanRequiredAssessment> requiredAssessments { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

