﻿using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace Michigan.Ods.Sdk.Models 
{
    public class Revenue 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// A reference to the related EducationOrganization resource.
        /// </summary>
        public EducationOrganizationReference educationOrganizationReference { get; set; }

        /// <summary>
        /// Denotes the fiscal year for which the revenue is submitted.
        /// </summary>
        public int? fiscalYear { get; set; }

        /// <summary>
        /// The independent fisal and accounting entity for revenue transaction.
        /// </summary>
        public string fundCodeDescriptor { get; set; }

        /// <summary>
        /// The basic account identifier for recording transactions.
        /// </summary>
        public string majorClassDescriptor { get; set; }

        /// <summary>
        /// The code used to further define/distinguish between revenue sources.
        /// </summary>
        public string suffixDescriptor { get; set; }

        /// <summary>
        /// An optional field. Is included in the Michigan School Accounting Manual Chart of Accounts but is not required for the FID collection.
        /// </summary>
        public string optional { get; set; }

        /// <summary>
        /// Amount for the fund code / major class code submitted.
        /// </summary>
        public double? amount { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

