﻿using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace Michigan.Ods.Sdk.Models 
{
    public class Session 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// A reference to the related School resource.
        /// </summary>
        public SchoolReference schoolReference { get; set; }

        /// <summary>
        /// A reference to the related SchoolYearType resource.
        /// </summary>
        public SchoolYearTypeReference schoolYearTypeReference { get; set; }

        /// <summary>
        /// The term for the Session during the school year.
        /// </summary>
        public string termDescriptor { get; set; }

        /// <summary>
        /// The identifier for the calendar for the academic session (e.g., 2010/11, 2011 Summer).
        /// </summary>
        public string name { get; set; }

        /// <summary>
        /// Month, day, and year of the first day of the Session.
        /// </summary>
        public DateTime? beginDate { get; set; }

        /// <summary>
        /// Month, day, and year of the last day of the Session.
        /// </summary>
        public DateTime? endDate { get; set; }

        /// <summary>
        /// The total number of instructional days in the school calendar.
        /// </summary>
        public int? totalInstructionalDays { get; set; }

        /// <summary>
        /// (MI EXT) Indicates status (OneRoster academicSession.status) of the Session.
        /// </summary>
        public string statusDescriptor { get; set; }

        /// <summary>
        /// (MI EXT) Indicates the category  (OneRoster type) of the Session.
        /// </summary>
        public string categoryDescriptor { get; set; }

        /// <summary>
        /// An unordered collection of sessionAcademicWeeks.  The academic weeks associated with the school year.
        /// </summary>
        public List<SessionAcademicWeek> academicWeeks { get; set; }

        /// <summary>
        /// An unordered collection of sessionGradingPeriods.  Grading periods associated with the calendar.
        /// </summary>
        public List<SessionGradingPeriod> gradingPeriods { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

