﻿using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace Michigan.Ods.Sdk.Models 
{
    public class StudentAcademicRecord 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// A reference to the related EducationOrganization resource.
        /// </summary>
        public EducationOrganizationReference educationOrganizationReference { get; set; }

        /// <summary>
        /// A reference to the related SchoolYearType resource.
        /// </summary>
        public SchoolYearTypeReference schoolYearTypeReference { get; set; }

        /// <summary>
        /// A reference to the related Student resource.
        /// </summary>
        public StudentReference studentReference { get; set; }

        /// <summary>
        /// The term for the session during the school year.
        /// </summary>
        public string termDescriptor { get; set; }

        /// <summary>
        /// The value of credits or units of value awarded for the completion of a course.
        /// </summary>
        public double? cumulativeEarnedCredits { get; set; }

        /// <summary>
        /// The type of credits or units of value awarded for the completion of a course.
        /// </summary>
        public string cumulativeEarnedCreditType { get; set; }

        /// <summary>
        /// Conversion factor that when multiplied by the number of credits is equivalent to Carnegie units.
        /// </summary>
        public double? cumulativeEarnedCreditConversion { get; set; }

        /// <summary>
        /// The value of credits or units of value awarded for the completion of a course.
        /// </summary>
        public double? cumulativeAttemptedCredits { get; set; }

        /// <summary>
        /// The type of credits or units of value awarded for the completion of a course.
        /// </summary>
        public string cumulativeAttemptedCreditType { get; set; }

        /// <summary>
        /// Conversion factor that when multiplied by the number of credits is equivalent to Carnegie units.
        /// </summary>
        public double? cumulativeAttemptedCreditConversion { get; set; }

        /// <summary>
        /// The cumulative number of grade points an individual earns by successfully completing courses or examinations during his or her enrollment in the current school as well as those transferred from schools in which the individual had been previously enrolled.
        /// </summary>
        public double? cumulativeGradePointsEarned { get; set; }

        /// <summary>
        /// A measure of average performance in all courses taken by an individual during his or her school career as determined for record-keeping purposes. This is obtained by dividing the total grade points received by the total number of credits attempted. This usually includes grade points received and credits attempted in his or her current school as well as those transferred from schools in which the individual was previously enrolled.
        /// </summary>
        public double? cumulativeGradePointAverage { get; set; }

        /// <summary>
        /// The scale of equivalents, if applicable, for grades awarded as indicators of performance in schoolwork. For example, numerical equivalents for letter grades used in determining a student's Grade Point Average (A=4, B=3, C=2, D=1 in a four-point system) or letter equivalents for percentage grades (90-100%=A, 80-90%=B, etc.)
        /// </summary>
        public string gradeValueQualifier { get; set; }

        /// <summary>
        /// The month and year the student is projected to graduate.
        /// </summary>
        public DateTime? projectedGraduationDate { get; set; }

        /// <summary>
        /// The value of credits or units of value awarded for the completion of a course.
        /// </summary>
        public double? sessionEarnedCredits { get; set; }

        /// <summary>
        /// The type of credits or units of value awarded for the completion of a course.
        /// </summary>
        public string sessionEarnedCreditType { get; set; }

        /// <summary>
        /// Conversion factor that when multiplied by the number of credits is equivalent to Carnegie units.
        /// </summary>
        public double? sessionEarnedCreditConversion { get; set; }

        /// <summary>
        /// The value of credits or units of value awarded for the completion of a course.
        /// </summary>
        public double? sessionAttemptedCredits { get; set; }

        /// <summary>
        /// The type of credits or units of value awarded for the completion of a course.
        /// </summary>
        public string sessionAttemptedCreditType { get; set; }

        /// <summary>
        /// Conversion factor that when multiplied by the number of credits is equivalent to Carnegie units.
        /// </summary>
        public double? sessionAttemptedCreditConversion { get; set; }

        /// <summary>
        /// The number of grade points an individual earned for this session.
        /// </summary>
        public double? sessionGradePointsEarned { get; set; }

        /// <summary>
        /// The grade point average for an individual computed as the grade points earned during the session divided by the number of credits attempted.
        /// </summary>
        public double? sessionGradePointAverage { get; set; }

        /// <summary>
        /// The academic rank information of a student in relation to his or her graduating class.
        /// </summary>
        public StudentAcademicRecordClassRanking classRanking { get; set; }

        /// <summary>
        /// An unordered collection of studentAcademicRecordAcademicHonors.  Academic distinctions earned by or awarded to the student.
        /// </summary>
        public List<StudentAcademicRecordAcademicHonor> academicHonors { get; set; }

        /// <summary>
        /// An unordered collection of studentAcademicRecordDiplomas.  Diploma(s) earned by the student.
        /// </summary>
        public List<StudentAcademicRecordDiploma> diplomas { get; set; }

        /// <summary>
        /// An unordered collection of studentAcademicRecordRecognitions.  Recognitions given to the student for accomplishments in a co-curricular or extracurricular activity.
        /// </summary>
        public List<StudentAcademicRecordRecognition> recognitions { get; set; }

        /// <summary>
        /// An unordered collection of studentAcademicRecordReportCards.  Report cards for the student.
        /// </summary>
        public List<StudentAcademicRecordReportCard> reportCards { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

