﻿using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace Michigan.Ods.Sdk.Models 
{
    public class StudentSpecialEducationProgramAssociation 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// A reference to the related EducationOrganization resource.
        /// </summary>
        public EducationOrganizationReference educationOrganizationReference { get; set; }

        /// <summary>
        /// A reference to the related Program resource.
        /// </summary>
        public ProgramReference programReference { get; set; }

        /// <summary>
        /// A reference to the related Student resource.
        /// </summary>
        public StudentReference studentReference { get; set; }

        /// <summary>
        /// The month, day, and year on which the Student first received services.
        /// </summary>
        public DateTime? beginDate { get; set; }

        /// <summary>
        /// The month, day, and year on which the Student exited the Program or stopped receiving services.
        /// </summary>
        public DateTime? endDate { get; set; }

        /// <summary>
        /// The reason the child left the Program within a school or district.
        /// </summary>
        public string reasonExitedDescriptor { get; set; }

        /// <summary>
        /// Indicates whether the student received services during the summer session or between sessions.
        /// </summary>
        public bool? servedOutsideOfRegularSession { get; set; }

        /// <summary>
        /// Added for ELI enrollment status.
        /// </summary>
        public string enrollmentStatus { get; set; }

        /// <summary>
        /// Indicator of the eligibility of the student to receive special education services according to the Individuals with Disabilities Education Act (IDEA).
        /// </summary>
        public bool? ideaEligibility { get; set; }

        /// <summary>
        /// The major instructional setting (more than 50 percent of a student's special education program).
        /// </summary>
        public string specialEducationSettingDescriptor { get; set; }

        /// <summary>
        /// The number of hours per week for special education instruction and therapy.
        /// </summary>
        public double? specialEducationHoursPerWeek { get; set; }

        /// <summary>
        /// Indicate the total number of hours of instructional time per week for the school that the student attends.
        /// </summary>
        public double? schoolHoursPerWeek { get; set; }

        /// <summary>
        /// Indicates whether the Student receiving special education and related services has been designated as multiply disabled by the admission, review, and dismissal committee as aligned with federal requirements.
        /// </summary>
        public bool? multiplyDisabled { get; set; }

        /// <summary>
        /// Indicates whether the Student receiving special education and related services is:          1) in the age range of birth to 22 years, and          2) has a serious, ongoing illness or a chronic condition that has lasted or is anticipated to last at least 12 or more months or has required at least one month of hospitalization, and that requires daily, ongoing medical treatments and monitoring by appropriately trained personnel which may include parents or other family members, and          3) requires the routine use of medical device or of assistive technology to compensate for the loss of usefulness of a body function needed to participate in activities of daily living, and          4) lives with ongoing threat to his or her continued well-being.          Aligns with federal requirements.
        /// </summary>
        public bool? medicallyFragile { get; set; }

        /// <summary>
        /// The date of the last special education evaluation.
        /// </summary>
        public DateTime? lastEvaluationDate { get; set; }

        /// <summary>
        /// The date of the last IEP review.
        /// </summary>
        public DateTime? iepReviewDate { get; set; }

        /// <summary>
        /// The effective date of the most recent IEP.
        /// </summary>
        public DateTime? iepBeginDate { get; set; }

        /// <summary>
        /// The end date of the most recent IEP.
        /// </summary>
        public DateTime? iepEndDate { get; set; }

        /// <summary>
        /// The date of the notice/offer of a Free Appropriate Public Education (FAPE) associated with the student's most recent individualized education program (IEP).
        /// </summary>
        public DateTime? planDate { get; set; }

        /// <summary>
        /// The full-time equivalency (FTE) for which the student is eligible for special education programs or services provided only to students with disabilities who do not qualify for Section 52 membership.
        /// </summary>
        public double? section52FTE { get; set; }

        /// <summary>
        /// The full-time equivalency (FTE) for which the student is eligible for special education programs or services, provided only to students with disabilities who qualify for Section 53 membership.
        /// </summary>
        public double? section53FTE { get; set; }

        /// <summary>
        /// The date on which the entity received the signed Parental Consent to Evaluate form. It is the beginning of the timeline for completion of the initial IEP.
        /// </summary>
        public DateTime? dateOfParentalConsent { get; set; }

        /// <summary>
        /// The number of calendar days that the evaluation and completion of the initial IEP went beyond the 30 school-day timeline or agreed-upon written extension.
        /// </summary>
        public int? daysBeyondTimeline { get; set; }

        /// <summary>
        /// The completion of an initial individualized education program (IEP) is the date on the notice of the offer of a free appropriate public education (FAPE).
        /// </summary>
        public DateTime? initialIEPCompletionDate { get; set; }

        /// <summary>
        /// Indicates the timeliness of the IEP by the child's third birthday for all children referred by Part C as potentially eligible for Part B.
        /// </summary>
        public string partCTransitionTimelinessDescriptor { get; set; }

        /// <summary>
        /// The outcome of the initial IEP determining if the student is eligible or ineligible for special education programs and services.
        /// </summary>
        public string resultOfInitialIEPDescriptor { get; set; }

        /// <summary>
        /// The timeliness status for the evaluation of eligibility. 
        /// </summary>
        public string timelinessOfInitialIEPDescriptor { get; set; }

        /// <summary>
        /// To indicate the  type of plan a child is receiving services under.
        /// </summary>
        public string typeOfPlanDescriptor { get; set; }

        /// <summary>
        /// This is used to report additional IEPs, IFSPs, or Non Public Service Plans that may have occurred prior to the current Plan Date.
        /// </summary>
        public DateTime? additionalPlanDate { get; set; }

        /// <summary>
        /// An unordered collection of studentProgramAssociationServices.  Indicates the Service(s) being provided to the Student by the Program.
        /// </summary>
        public List<StudentProgramAssociationService> services { get; set; }

        /// <summary>
        /// An unordered collection of studentSpecialEducationProgramAssociationProgramSupports.  To indicate support services student receives through program.
        /// </summary>
        public List<StudentSpecialEducationProgramAssociationProgramSupport> programSupports { get; set; }

        /// <summary>
        /// An unordered collection of studentSpecialEducationProgramAssociationServiceProviders.  The staff providing Special Education services to the student.
        /// </summary>
        public List<StudentSpecialEducationProgramAssociationServiceProvider> serviceProviders { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

