﻿using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace Michigan.Ods.Sdk.Profiles.Alert.Models 
{
    public class Staff_Readable 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// A unique alphanumeric code assigned to a staff.
        /// </summary>
        public string staffUniqueId { get; set; }

        /// <summary>
        /// A prefix used to denote the title, degree, position, or seniority of the person.
        /// </summary>
        public string personalTitlePrefix { get; set; }

        /// <summary>
        /// A name given to an individual at birth, baptism, or during another naming ceremony, or through legal change.
        /// </summary>
        public string firstName { get; set; }

        /// <summary>
        /// A secondary name given to an individual at birth, baptism, or during another naming ceremony.
        /// </summary>
        public string middleName { get; set; }

        /// <summary>
        /// The name borne in common by members of a family.
        /// </summary>
        public string lastSurname { get; set; }

        /// <summary>
        /// An appendage, if any, used to denote an individual's generation in his family (e.g., Jr., Sr., III).
        /// </summary>
        public string generationCodeSuffix { get; set; }

        /// <summary>
        /// A person's gender.
        /// </summary>
        public string sexType { get; set; }

        /// <summary>
        /// An unordered collection of staffElectronicMails.  The numbers, letters, and symbols used to identify an electronic mail (e-mail) user within the network to which the individual or organization belongs.
        /// </summary>
        public List<StaffElectronicMail_Readable> electronicMails { get; set; }

        /// <summary>
        /// An unordered collection of staffIdentificationCodes.  A unique number or alphanumeric code assigned to a staff member by a school, school system, a state, or other agency or entity.
        /// </summary>
        public List<StaffIdentificationCode_Readable> identificationCodes { get; set; }

        /// <summary>
        /// An unordered collection of staffLanguages.  The language(s) the individual uses to communicate.
        /// </summary>
        public List<StaffLanguage_Readable> languages { get; set; }

        /// <summary>
        /// An unordered collection of staffTelephones.  The 10-digit telephone number, including the area code, for the person.
        /// </summary>
        public List<StaffTelephone_Readable> telephones { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

