﻿using System;
using System.Collections.Generic;
using System.Linq;
using Michigan.Ods.Sdk.Helpers;
using Michigan.Ods.Sdk.Profiles.Assessment.Models;
using RestSharp;
  using System.Net;
  using System.Text;
  
namespace Michigan.Ods.Sdk.Profiles.Assessment.Api 
{
    public class SessionsApi 
    {
        private readonly IRestClient client;

        public SessionsApi(IRestClient client)
        {
            this.client = client;
        }
      
        /// <summary>
        /// Retrieves resources based with paging capabilities (using the &quot;Get All&quot; pattern). This GET operation provides access to resources using the &quot;Get All&quot; pattern. In this version of the API there is support for paging.
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<Session_Readable>> GetSessionsAll(int? offset= null, int? limit= null) 
        {
            var request = new RestRequest("/sessions", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            request.AddHeader("Accept", "application/vnd.ed-fi.session.assessment.readable+json");
            var response = client.Execute<List<Session_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves resources matching values of an example resource (using the &quot;Get By Example&quot; pattern). This GET operation provides access to resources using the &quot;Get by Example&quot; search pattern.  The values of any properties of the resource that are specified will be used to return all matching results (if it exists).
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <param name="schoolId">The identifier assigned to a school by the State Education Agency (SEA).</param>
        /// <param name="schoolYear">The identifier for the school year.</param>
        /// <param name="termDescriptor">The term for the Session during the school year.</param>
        /// <param name="name">The identifier for the calendar for the academic session (e.g., 2010/11, 2011 Summer).</param>
        /// <param name="beginDate">Month, day, and year of the first day of the Session.</param>
        /// <param name="endDate">Month, day, and year of the last day of the Session.</param>
        /// <param name="totalInstructionalDays">The total number of instructional days in the school calendar.</param>
        /// <param name="id"></param>
        /// <param name="statusDescriptor">(MI EXT) Indicates status (OneRoster academicSession.status) of the Session.</param>
        /// <param name="categoryDescriptor">(MI EXT) Indicates the category  (OneRoster type) of the Session.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<Session_Readable>> GetSessionsAll(int? offset= null, int? limit= null, int? schoolId= null, int? schoolYear= null, string termDescriptor= null, string name= null, DateTime? beginDate= null, DateTime? endDate= null, int? totalInstructionalDays= null, string id= null, string statusDescriptor= null, string categoryDescriptor= null) 
        {
            var request = new RestRequest("/sessions", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            if (schoolId != null)
                request.AddParameter("schoolId", schoolId);
            if (schoolYear != null)
                request.AddParameter("schoolYear", schoolYear);
            if (termDescriptor != null)
                request.AddParameter("termDescriptor", termDescriptor);
            if (name != null)
                request.AddParameter("name", name);
            if (beginDate != null)
                request.AddParameter("beginDate", beginDate);
            if (endDate != null)
                request.AddParameter("endDate", endDate);
            if (totalInstructionalDays != null)
                request.AddParameter("totalInstructionalDays", totalInstructionalDays);
            if (id != null)
                request.AddParameter("id", id);
            if (statusDescriptor != null)
                request.AddParameter("statusDescriptor", statusDescriptor);
            if (categoryDescriptor != null)
                request.AddParameter("categoryDescriptor", categoryDescriptor);
            request.AddHeader("Accept", "application/vnd.ed-fi.session.assessment.readable+json");
            var response = client.Execute<List<Session_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the values of the resource's natural key (using the &quot;Get By Key&quot; pattern). This GET operation provides access to resources using the &quot;Get by Key&quot; search pattern. The values of the natural key of the resource must be fully specified, and the service will return the matching result (if it exists).
        /// </summary>
        /// <param name="schoolId">The identifier assigned to a school by the State Education Agency (SEA).</param>
        /// <param name="schoolYear">The identifier for the school year.</param>
        /// <param name="termDescriptor">The term for the Session during the school year.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<Session_Readable> GetSessionByKey(int? schoolId, int? schoolYear, string termDescriptor, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/sessions", Method.GET);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (schoolId == null || schoolYear == null || termDescriptor == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            if (schoolId != null)
                request.AddParameter("schoolId", schoolId);
            if (schoolYear != null)
                request.AddParameter("schoolYear", schoolYear);
            if (termDescriptor != null)
                request.AddParameter("termDescriptor", termDescriptor);
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.session.assessment.readable+json");
            var response = client.Execute<Session_Readable>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the resource's identifier (using the &quot;Get By Id&quot; pattern). This GET operation retrieves a resource by the specified resource identifier.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be retrieved.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<Session_Readable> GetSessionsById(string id, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/sessions/{id}", Method.GET);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.session.assessment.readable+json");
            var response = client.Execute<Session_Readable>(request);

            return response;
        }
        /// <summary>
        /// Deletes an existing resource using the resource identifier. The DELETE operation is used to delete an existing resource by identifier.  If the resource doesn't exist, an error will result (the resource will not be found).
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be deleted.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the DELETE from removing a resource modified by another consumer.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse DeleteSessionById(string id, string IfMatch= null) 
        {
            var request = new RestRequest("/sessions/{id}", Method.DELETE);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            var response = client.Execute(request);

            return response;
        }
        // patch operation generation was suppressed because profiles can not support patch
    }
}

