﻿using System;
using System.Collections.Generic;
using System.Linq;
using Michigan.Ods.Sdk.Helpers;
using Michigan.Ods.Sdk.Profiles.DataWarehouse.Models;
using RestSharp;
  using System.Net;
  using System.Text;
  
namespace Michigan.Ods.Sdk.Profiles.DataWarehouse.Api 
{
    public class CoursesApi 
    {
        private readonly IRestClient client;

        public CoursesApi(IRestClient client)
        {
            this.client = client;
        }
      
        /// <summary>
        /// Retrieves resources based with paging capabilities (using the &quot;Get All&quot; pattern). This GET operation provides access to resources using the &quot;Get All&quot; pattern. In this version of the API there is support for paging.
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<Course_Readable>> GetCoursesAll(int? offset= null, int? limit= null) 
        {
            var request = new RestRequest("/courses", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            request.AddHeader("Accept", "application/vnd.ed-fi.course.datawarehouse.readable+json");
            var response = client.Execute<List<Course_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves resources matching values of an example resource (using the &quot;Get By Example&quot; pattern). This GET operation provides access to resources using the &quot;Get by Example&quot; search pattern.  The values of any properties of the resource that are specified will be used to return all matching results (if it exists).
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <param name="educationOrganizationId">The identifier assigned to an education agency by the State Education Agency (SEA).  Also known as the State LEA ID.</param>
        /// <param name="code">A unique alphanumeric code assigned to a course.</param>
        /// <param name="title">The descriptive name given to a course of study offered in a school or other institution or organization. In departmentalized classes at the elementary, secondary, and postsecondary levels (and for staff development activities), this refers to the name by which a course is identified (e.g., American History, English III). For elementary and other non-departmentalized classes, it refers to any portion of the instruction for which a grade or report is assigned (e.g., reading, composition, spelling, and language arts).</param>
        /// <param name="numberOfParts">The number of parts identified for a course.</param>
        /// <param name="academicSubjectDescriptor">The intended major subject area of the course.</param>
        /// <param name="description">A description of the content standards and goals covered in the course. Reference may be made to state or national content standards.</param>
        /// <param name="timeRequiredForCompletion">The actual or estimated number of clock minutes required for class completion.  This number is especially important for career and technical education classes and may represent (in minutes) the clock hour requirement of the class.</param>
        /// <param name="dateCourseAdopted">Date the course was adopted by the education agency.</param>
        /// <param name="highSchoolCourseRequirement">An indication that this course may satisfy high school graduation requirements in the course's subject area.</param>
        /// <param name="gpaApplicabilityType">An indicator of whether or not the course being described is included in the computation of the student's Grade Point Average, and if so, if it is weighted differently from regular courses.</param>
        /// <param name="definedByType">Specifies whether the course was defined by the SEA, LEA, School, or national organization.</param>
        /// <param name="minimumAvailableCredits">The value of credits or units of value awarded for the completion of a course.</param>
        /// <param name="minimumAvailableCreditType">The type of credits or units of value awarded for the completion of a course.</param>
        /// <param name="minimumAvailableCreditConversion">Conversion factor that when multiplied by the number of credits is equivalent to Carnegie units.</param>
        /// <param name="maximumAvailableCredits">The value of credits or units of value awarded for the completion of a course.</param>
        /// <param name="maximumAvailableCreditType">The type of credits or units of value awarded for the completion of a course.</param>
        /// <param name="maximumAvailableCreditConversion">Conversion factor that when multiplied by the number of credits is equivalent to Carnegie units.</param>
        /// <param name="careerPathwayType">Indicates the career cluster or pathway the course is associated with as part of a CTE curriculum.</param>
        /// <param name="id"></param>
        /// <param name="typeLevelAndRigorDescriptor">(MI EXT) Indicates the level and rigor of the instruction provided throughout the reported course. Code 07 is to be used for college instructed courses for which the student will receive high school credit. The student may be participating in an Early/Middle College program or a dual enrollment program.</param>
        /// <param name="statusDescriptor">(MI EXT) Indicates status (OneRoster courses.status) of the Course.</param>
        /// <param name="eligible64bCourse">(MI EXT) This course is eligible for the 64b dual enrollment funding incentive.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<Course_Readable>> GetCoursesAll(int? offset= null, int? limit= null, int? educationOrganizationId= null, string code= null, string title= null, int? numberOfParts= null, string academicSubjectDescriptor= null, string description= null, int? timeRequiredForCompletion= null, DateTime? dateCourseAdopted= null, bool? highSchoolCourseRequirement= null, string gpaApplicabilityType= null, string definedByType= null, double? minimumAvailableCredits= null, string minimumAvailableCreditType= null, double? minimumAvailableCreditConversion= null, double? maximumAvailableCredits= null, string maximumAvailableCreditType= null, double? maximumAvailableCreditConversion= null, string careerPathwayType= null, string id= null, string typeLevelAndRigorDescriptor= null, string statusDescriptor= null, bool? eligible64bCourse= null) 
        {
            var request = new RestRequest("/courses", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            if (educationOrganizationId != null)
                request.AddParameter("educationOrganizationId", educationOrganizationId);
            if (code != null)
                request.AddParameter("code", code);
            if (title != null)
                request.AddParameter("title", title);
            if (numberOfParts != null)
                request.AddParameter("numberOfParts", numberOfParts);
            if (academicSubjectDescriptor != null)
                request.AddParameter("academicSubjectDescriptor", academicSubjectDescriptor);
            if (description != null)
                request.AddParameter("description", description);
            if (timeRequiredForCompletion != null)
                request.AddParameter("timeRequiredForCompletion", timeRequiredForCompletion);
            if (dateCourseAdopted != null)
                request.AddParameter("dateCourseAdopted", dateCourseAdopted);
            if (highSchoolCourseRequirement != null)
                request.AddParameter("highSchoolCourseRequirement", highSchoolCourseRequirement);
            if (gpaApplicabilityType != null)
                request.AddParameter("gpaApplicabilityType", gpaApplicabilityType);
            if (definedByType != null)
                request.AddParameter("definedByType", definedByType);
            if (minimumAvailableCredits != null)
                request.AddParameter("minimumAvailableCredits", minimumAvailableCredits);
            if (minimumAvailableCreditType != null)
                request.AddParameter("minimumAvailableCreditType", minimumAvailableCreditType);
            if (minimumAvailableCreditConversion != null)
                request.AddParameter("minimumAvailableCreditConversion", minimumAvailableCreditConversion);
            if (maximumAvailableCredits != null)
                request.AddParameter("maximumAvailableCredits", maximumAvailableCredits);
            if (maximumAvailableCreditType != null)
                request.AddParameter("maximumAvailableCreditType", maximumAvailableCreditType);
            if (maximumAvailableCreditConversion != null)
                request.AddParameter("maximumAvailableCreditConversion", maximumAvailableCreditConversion);
            if (careerPathwayType != null)
                request.AddParameter("careerPathwayType", careerPathwayType);
            if (id != null)
                request.AddParameter("id", id);
            if (typeLevelAndRigorDescriptor != null)
                request.AddParameter("typeLevelAndRigorDescriptor", typeLevelAndRigorDescriptor);
            if (statusDescriptor != null)
                request.AddParameter("statusDescriptor", statusDescriptor);
            if (eligible64bCourse != null)
                request.AddParameter("eligible64bCourse", eligible64bCourse);
            request.AddHeader("Accept", "application/vnd.ed-fi.course.datawarehouse.readable+json");
            var response = client.Execute<List<Course_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the values of the resource's natural key (using the &quot;Get By Key&quot; pattern). This GET operation provides access to resources using the &quot;Get by Key&quot; search pattern. The values of the natural key of the resource must be fully specified, and the service will return the matching result (if it exists).
        /// </summary>
        /// <param name="educationOrganizationId">The identifier assigned to an education agency by the State Education Agency (SEA).  Also known as the State LEA ID.</param>
        /// <param name="code">A unique alphanumeric code assigned to a course.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<Course_Readable> GetCourseByKey(int? educationOrganizationId, string code, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/courses", Method.GET);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (educationOrganizationId == null || code == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            if (educationOrganizationId != null)
                request.AddParameter("educationOrganizationId", educationOrganizationId);
            if (code != null)
                request.AddParameter("code", code);
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.course.datawarehouse.readable+json");
            var response = client.Execute<Course_Readable>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the resource's identifier (using the &quot;Get By Id&quot; pattern). This GET operation retrieves a resource by the specified resource identifier.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be retrieved.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<Course_Readable> GetCoursesById(string id, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/courses/{id}", Method.GET);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.course.datawarehouse.readable+json");
            var response = client.Execute<Course_Readable>(request);

            return response;
        }
        /// <summary>
        /// Deletes an existing resource using the resource identifier. The DELETE operation is used to delete an existing resource by identifier.  If the resource doesn't exist, an error will result (the resource will not be found).
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be deleted.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the DELETE from removing a resource modified by another consumer.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse DeleteCourseById(string id, string IfMatch= null) 
        {
            var request = new RestRequest("/courses/{id}", Method.DELETE);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            var response = client.Execute(request);

            return response;
        }
        // patch operation generation was suppressed because profiles can not support patch
    }
}

