﻿using System;
using System.Collections.Generic;
using System.Linq;
using Michigan.Ods.Sdk.Helpers;
using Michigan.Ods.Sdk.Profiles.EEM.Models;
using RestSharp;
  using System.Net;
  using System.Text;
  
namespace Michigan.Ods.Sdk.Profiles.EEM.Api 
{
    public class EemProsperityRegionDescriptorsApi 
    {
        private readonly IRestClient client;

        public EemProsperityRegionDescriptorsApi(IRestClient client)
        {
            this.client = client;
        }
      
        /// <summary>
        /// Retrieves resources based with paging capabilities (using the &quot;Get All&quot; pattern). This GET operation provides access to resources using the &quot;Get All&quot; pattern. In this version of the API there is support for paging.
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<EemProsperityRegionDescriptor_Readable>> GetEEMProsperityRegionDescriptorsAll(int? offset= null, int? limit= null) 
        {
            var request = new RestRequest("/eemProsperityRegionDescriptors", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            request.AddHeader("Accept", "application/vnd.ed-fi.eemprosperityregiondescriptor.eem.readable+json");
            var response = client.Execute<List<EemProsperityRegionDescriptor_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves resources matching values of an example resource (using the &quot;Get By Example&quot; pattern). This GET operation provides access to resources using the &quot;Get by Example&quot; search pattern.  The values of any properties of the resource that are specified will be used to return all matching results (if it exists).
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <param name="eemProsperityRegionDescriptorId">A unique identifier used as Primary Key, not derived from business logic, when acting as Foreign Key, references the parent table.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<EemProsperityRegionDescriptor_Readable>> GetEEMProsperityRegionDescriptorsAll(int? offset= null, int? limit= null, int? eemProsperityRegionDescriptorId= null) 
        {
            var request = new RestRequest("/eemProsperityRegionDescriptors", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            if (eemProsperityRegionDescriptorId != null)
                request.AddParameter("eemProsperityRegionDescriptorId", eemProsperityRegionDescriptorId);
            request.AddHeader("Accept", "application/vnd.ed-fi.eemprosperityregiondescriptor.eem.readable+json");
            var response = client.Execute<List<EemProsperityRegionDescriptor_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the values of the resource's natural key (using the &quot;Get By Key&quot; pattern). This GET operation provides access to resources using the &quot;Get by Key&quot; search pattern. The values of the natural key of the resource must be fully specified, and the service will return the matching result (if it exists).
        /// </summary>
        /// <param name="eemProsperityRegionDescriptorId">A unique identifier used as Primary Key, not derived from business logic, when acting as Foreign Key, references the parent table.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<EemProsperityRegionDescriptor_Readable> GetEEMProsperityRegionDescriptorByKey(int? eemProsperityRegionDescriptorId, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/eemProsperityRegionDescriptors", Method.GET);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (eemProsperityRegionDescriptorId == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            if (eemProsperityRegionDescriptorId != null)
                request.AddParameter("eemProsperityRegionDescriptorId", eemProsperityRegionDescriptorId);
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.eemprosperityregiondescriptor.eem.readable+json");
            var response = client.Execute<EemProsperityRegionDescriptor_Readable>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the resource's identifier (using the &quot;Get By Id&quot; pattern). This GET operation retrieves a resource by the specified resource identifier.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be retrieved.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<EemProsperityRegionDescriptor_Readable> GetEEMProsperityRegionDescriptorsById(string id, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/eemProsperityRegionDescriptors/{id}", Method.GET);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.eemprosperityregiondescriptor.eem.readable+json");
            var response = client.Execute<EemProsperityRegionDescriptor_Readable>(request);

            return response;
        }
        /// <summary>
        /// Deletes an existing resource using the resource identifier. The DELETE operation is used to delete an existing resource by identifier.  If the resource doesn't exist, an error will result (the resource will not be found).
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be deleted.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the DELETE from removing a resource modified by another consumer.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse DeleteEEMProsperityRegionDescriptorById(string id, string IfMatch= null) 
        {
            var request = new RestRequest("/eemProsperityRegionDescriptors/{id}", Method.DELETE);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            var response = client.Execute(request);

            return response;
        }
        // patch operation generation was suppressed because profiles can not support patch
    }
}

