﻿using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace Michigan.Ods.Sdk.Profiles.EEM.Models 
{
    public class EemEducationalEntityMaster_Writable 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// A reference to the related EEMCounty resource.
        /// </summary>
        public EemCountyReference eemCountyReference { get; set; }

        /// <summary>
        /// A reference to the related EEMCounty resource.
        /// </summary>
        public EemCountyReference geographicEEMCountyReference { get; set; }

        /// <summary>
        /// A reference to the related EEMEducationalEntityMaster resource.
        /// </summary>
        public EemEducationalEntityMasterReference previousDistrictEEMEducationalEntityMasterReference { get; set; }

        /// <summary>
        /// A reference to the related EEMEntityTypeClassification resource.
        /// </summary>
        public EemEntityTypeClassificationReference eemEntityTypeClassificationReference { get; set; }

        /// <summary>
        /// Educational Entity Master identifier from EEM system.
        /// </summary>
        public int? eemEducationalEntityMasterId { get; set; }

        /// <summary>
        /// The EEM official name of the Educational Entity
        /// </summary>
        public string eemEntityOfficialName { get; set; }

        /// <summary>
        /// This characteristic denotes the actual opening date of the entity or when it begins to do business. *** needs to be datetime ***
        /// </summary>
        public DateTime? openDate { get; set; }

        /// <summary>
        /// This characteristic is the actual closing date of the entity or the date the entity ceased to do business. *** needs to be datetime ***
        /// </summary>
        public DateTime? closeDate { get; set; }

        /// <summary>
        /// Indicates the reason why an Educational Entity was closed.
        /// </summary>
        public string eemCloseReasonDescriptor { get; set; }

        /// <summary>
        /// Indicates the education organization provides both a high school education as well as up to 60 college credits.
        /// </summary>
        public bool? earlyMiddleCollegeFlag { get; set; }

        /// <summary>
        /// FiscalEntityCode as indicated in EEM.
        /// </summary>
        public string eemFiscalEntityTypeDescriptor { get; set; }

        /// <summary>
        /// Denotes the EEM open / close status of the entity.
        /// </summary>
        public string eemStatusDescriptor { get; set; }

        /// <summary>
        /// An unordered collection of eemEducationalEntityMasterEEMAlternativeEducationServices.  Indicates the alternative education services provided.
        /// </summary>
        public List<EemEducationalEntityMasterEEMAlternativeEducationService_Writable> eemAlternativeEducationServices { get; set; }

        /// <summary>
        /// An unordered collection of eemEducationalEntityMasterEEMEntityContracts.  EEM Entity Contract details.
        /// </summary>
        public List<EemEducationalEntityMasterEEMEntityContract_Writable> eemEntityContracts { get; set; }

        /// <summary>
        /// An unordered collection of eemEducationalEntityMasterEEMEntityEducationalSettings.  Identifies the educational setting(s) for which this entity is authorized to provide instruction and actually provides instruction.
        /// </summary>
        public List<EemEducationalEntityMasterEEMEntityEducationalSetting_Writable> eemEntityEducationalSettings { get; set; }

        /// <summary>
        /// An unordered collection of eemEducationalEntityMasterEEMEntityGrades.  Identifies the grade level(s) for which this entity is authorized to provide instruction and for which it actually provides instruction.
        /// </summary>
        public List<EemEducationalEntityMasterEEMEntityGrade_Writable> eemEntityGrades { get; set; }

        /// <summary>
        /// An unordered collection of eemEducationalEntityMasterEEMEntitySchedules.  Indicates the schedule types of the EEM Educational Entity.
        /// </summary>
        public List<EemEducationalEntityMasterEEMEntitySchedule_Writable> eemEntitySchedules { get; set; }

        /// <summary>
        /// An unordered collection of eemEducationalEntityMasterEEMIdentificationCodes.  The unique number or alphanumeric code assigned to an Educational Entity by another entity (e.g., School, State, Agency).
        /// </summary>
        public List<EemEducationalEntityMasterEEMIdentificationCode_Writable> eemIdentificationCodes { get; set; }

        /// <summary>
        /// An unordered collection of eemEducationalEntityMasterEEMInstitutionAddresses.  The set of elements that describe the EEM institutional address of the Educational Entity.
        /// </summary>
        public List<EemEducationalEntityMasterEEMInstitutionAddress_Writable> eemInstitutionAddresses { get; set; }

        /// <summary>
        /// An unordered collection of eemEducationalEntityMasterEEMInstitutionElectronicMails.  The electronic mail of the Educational Entity.
        /// </summary>
        public List<EemEducationalEntityMasterEEMInstitutionElectronicMail_Writable> eemInstitutionElectronicMails { get; set; }

        /// <summary>
        /// An unordered collection of eemEducationalEntityMasterEEMInstitutionTelephones.  The telephone of the Educational Entity.
        /// </summary>
        public List<EemEducationalEntityMasterEEMInstitutionTelephone_Writable> eemInstitutionTelephones { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

