﻿using System;
using System.Collections.Generic;
using System.Linq;
using Michigan.Ods.Sdk.Helpers;
using Michigan.Ods.Sdk.Profiles.SIS.Models;
using RestSharp;
  using System.Net;
  using System.Text;
  
namespace Michigan.Ods.Sdk.Profiles.SIS.Api 
{
    public class CommunityProviderLocationsApi 
    {
        private readonly IRestClient client;

        public CommunityProviderLocationsApi(IRestClient client)
        {
            this.client = client;
        }
      
        /// <summary>
        /// Retrieves resources based with paging capabilities (using the &quot;Get All&quot; pattern). This GET operation provides access to resources using the &quot;Get All&quot; pattern. In this version of the API there is support for paging.
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<CommunityProviderLocation_Readable>> GetCommunityProviderLocationsAll(int? offset= null, int? limit= null) 
        {
            var request = new RestRequest("/communityProviderLocations", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            request.AddHeader("Accept", "application/vnd.ed-fi.communityproviderlocation.sis.readable+json");
            var response = client.Execute<List<CommunityProviderLocation_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves resources matching values of an example resource (using the &quot;Get By Example&quot; pattern). This GET operation provides access to resources using the &quot;Get by Example&quot; search pattern.  The values of any properties of the resource that are specified will be used to return all matching results (if it exists).
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <param name="communityProviderId">The identifier assigned to a Community Provider.</param>
        /// <param name="communityProviderLocationId">A unique number or alphanumeric code assigned to an education organization by a school, school system, a state, or other agency or entity.</param>
        /// <param name="ageRangeDescription">An indication of the range of ages of students that this provider location can accommodate.</param>
        /// <param name="youngestAgeAccepted">The youngest age of students accepted at this location.</param>
        /// <param name="oldestAgeAccepted">The oldest age of students accepted at this location.</param>
        /// <param name="capacity">The maximum number of students this provider location can accommodate at any given time.</param>
        /// <param name="specialNeedsProvidedFlag">An indication of whether a provider location serves children with special needs.</param>
        /// <param name="timeOpen">The time of day this provider location begins providing services.</param>
        /// <param name="timeClose">The time of day this provider location stops providing services.</param>
        /// <param name="addressType">The type of address listed for the community provider location.</param>
        /// <param name="streetNumberName">The street number and street name or post office box number of an address.</param>
        /// <param name="apartmentRoomSuiteNumber">The street number and street name or post office box number of an address.</param>
        /// <param name="buildingSiteNumber">The number of the building on the site, if more than one building shares the same address.</param>
        /// <param name="city">The name of the city in which an address is located.</param>
        /// <param name="stateAbbreviationType">The abbreviation for the state (within the United States) or outlying area in which an address is located.</param>
        /// <param name="postalCode">The five or nine digit zip code or overseas postal code portion of an address.</param>
        /// <param name="nameOfCounty">The name of the county, parish, borough, or comparable unit (within a state) in which an address is located.</param>
        /// <param name="countyFIPSCode">The Federal Information Processing Standards (FIPS) numeric code for the county issued by the National Institute of Standards and Technology (NIST). Counties are considered to be the 'first-order subdivisions' of each State and statistically equivalent entity, regardless of their local designations (county, parish, borough, etc.). Counties in different States will have the same code. A unique county number is created when combined with the 2-digit FIPS State Code.</param>
        /// <param name="id"></param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<CommunityProviderLocation_Readable>> GetCommunityProviderLocationsAll(int? offset= null, int? limit= null, int? communityProviderId= null, int? communityProviderLocationId= null, string ageRangeDescription= null, int? youngestAgeAccepted= null, int? oldestAgeAccepted= null, int? capacity= null, bool? specialNeedsProvidedFlag= null, string timeOpen= null, string timeClose= null, string addressType= null, string streetNumberName= null, string apartmentRoomSuiteNumber= null, string buildingSiteNumber= null, string city= null, string stateAbbreviationType= null, string postalCode= null, string nameOfCounty= null, string countyFIPSCode= null, string id= null) 
        {
            var request = new RestRequest("/communityProviderLocations", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            if (communityProviderId != null)
                request.AddParameter("communityProviderId", communityProviderId);
            if (communityProviderLocationId != null)
                request.AddParameter("communityProviderLocationId", communityProviderLocationId);
            if (ageRangeDescription != null)
                request.AddParameter("ageRangeDescription", ageRangeDescription);
            if (youngestAgeAccepted != null)
                request.AddParameter("youngestAgeAccepted", youngestAgeAccepted);
            if (oldestAgeAccepted != null)
                request.AddParameter("oldestAgeAccepted", oldestAgeAccepted);
            if (capacity != null)
                request.AddParameter("capacity", capacity);
            if (specialNeedsProvidedFlag != null)
                request.AddParameter("specialNeedsProvidedFlag", specialNeedsProvidedFlag);
            if (timeOpen != null)
                request.AddParameter("timeOpen", timeOpen);
            if (timeClose != null)
                request.AddParameter("timeClose", timeClose);
            if (addressType != null)
                request.AddParameter("addressType", addressType);
            if (streetNumberName != null)
                request.AddParameter("streetNumberName", streetNumberName);
            if (apartmentRoomSuiteNumber != null)
                request.AddParameter("apartmentRoomSuiteNumber", apartmentRoomSuiteNumber);
            if (buildingSiteNumber != null)
                request.AddParameter("buildingSiteNumber", buildingSiteNumber);
            if (city != null)
                request.AddParameter("city", city);
            if (stateAbbreviationType != null)
                request.AddParameter("stateAbbreviationType", stateAbbreviationType);
            if (postalCode != null)
                request.AddParameter("postalCode", postalCode);
            if (nameOfCounty != null)
                request.AddParameter("nameOfCounty", nameOfCounty);
            if (countyFIPSCode != null)
                request.AddParameter("countyFIPSCode", countyFIPSCode);
            if (id != null)
                request.AddParameter("id", id);
            request.AddHeader("Accept", "application/vnd.ed-fi.communityproviderlocation.sis.readable+json");
            var response = client.Execute<List<CommunityProviderLocation_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the values of the resource's natural key (using the &quot;Get By Key&quot; pattern). This GET operation provides access to resources using the &quot;Get by Key&quot; search pattern. The values of the natural key of the resource must be fully specified, and the service will return the matching result (if it exists).
        /// </summary>
        /// <param name="communityProviderId">The identifier assigned to a Community Provider.</param>
        /// <param name="communityProviderLocationId">A unique number or alphanumeric code assigned to an education organization by a school, school system, a state, or other agency or entity.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<CommunityProviderLocation_Readable> GetCommunityProviderLocationByKey(int? communityProviderId, int? communityProviderLocationId, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/communityProviderLocations", Method.GET);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (communityProviderId == null || communityProviderLocationId == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            if (communityProviderId != null)
                request.AddParameter("communityProviderId", communityProviderId);
            if (communityProviderLocationId != null)
                request.AddParameter("communityProviderLocationId", communityProviderLocationId);
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.communityproviderlocation.sis.readable+json");
            var response = client.Execute<CommunityProviderLocation_Readable>(request);

            return response;
        }
        /// <summary>
        /// Creates or updates resources based on the natural key values of the supplied resource. The POST operation can be used to create or update resources. In database terms, this is often referred to as an &quot;upsert&quot; operation (insert + update).  Clients should NOT include the resource &quot;id&quot; in the JSON body because it will result in an error (you must use a PUT operation to update a resource by &quot;id&quot;). The web service will identify whether the resource already exists based on the natural key values provided, and update or create the resource appropriately.
        /// </summary>
        /// <param name="body">The JSON representation of the &quot;communityProviderLocation&quot; resource to be created or updated.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse PostCommunityProviderLocations(CommunityProviderLocation_Writable body) 
        {
            var request = new RestRequest("/communityProviderLocations", Method.POST);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (body == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddBody(body);
            request.Parameters.First(param => param.Type == ParameterType.RequestBody).Name = "application/vnd.ed-fi.communityproviderlocation.sis.writable+json";
            var response = client.Execute(request);

            var location = response.Headers.FirstOrDefault(x => x.Name == "Location");

            if (location != null && !string.IsNullOrWhiteSpace(location.Value.ToString()))
                body.id = location.Value.ToString().Split('/').Last();
            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the resource's identifier (using the &quot;Get By Id&quot; pattern). This GET operation retrieves a resource by the specified resource identifier.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be retrieved.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<CommunityProviderLocation_Readable> GetCommunityProviderLocationsById(string id, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/communityProviderLocations/{id}", Method.GET);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.communityproviderlocation.sis.readable+json");
            var response = client.Execute<CommunityProviderLocation_Readable>(request);

            return response;
        }
        /// <summary>
        /// Updates or creates a resource based on the resource identifier. The PUT operation is used to update or create a resource by identifier.  If the resource doesn't exist, the resource will be created using that identifier.  Additionally, natural key values cannot be changed using this operation, and will not be modified in the database.  If the resource &quot;id&quot; is provided in the JSON body, it will be ignored as well.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be updated.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the PUT from updating a resource modified by another consumer.</param>
        /// <param name="body">The JSON representation of the &quot;communityProviderLocation&quot; resource to be updated.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse PutCommunityProviderLocation(string id, string IfMatch, CommunityProviderLocation_Writable body) 
        {
            var request = new RestRequest("/communityProviderLocations/{id}", Method.PUT);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null || body == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            request.AddBody(body);
            request.Parameters.First(param => param.Type == ParameterType.RequestBody).Name = "application/vnd.ed-fi.communityproviderlocation.sis.writable+json";
            var response = client.Execute(request);

            var location = response.Headers.FirstOrDefault(x => x.Name == "Location");

            if (location != null && !string.IsNullOrWhiteSpace(location.Value.ToString()))
                body.id = location.Value.ToString().Split('/').Last();
            return response;
        }
        /// <summary>
        /// Deletes an existing resource using the resource identifier. The DELETE operation is used to delete an existing resource by identifier.  If the resource doesn't exist, an error will result (the resource will not be found).
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be deleted.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the DELETE from removing a resource modified by another consumer.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse DeleteCommunityProviderLocationById(string id, string IfMatch= null) 
        {
            var request = new RestRequest("/communityProviderLocations/{id}", Method.DELETE);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            var response = client.Execute(request);

            return response;
        }
        // patch operation generation was suppressed because profiles can not support patch
    }
}

