﻿using System;
using System.Collections.Generic;
using System.Linq;
using Michigan.Ods.Sdk.Helpers;
using Michigan.Ods.Sdk.Profiles.SIS.Models;
using RestSharp;
  using System.Net;
  using System.Text;
  
namespace Michigan.Ods.Sdk.Profiles.SIS.Api 
{
    public class EemCharacteristicsApi 
    {
        private readonly IRestClient client;

        public EemCharacteristicsApi(IRestClient client)
        {
            this.client = client;
        }
      
        /// <summary>
        /// Retrieves resources based with paging capabilities (using the &quot;Get All&quot; pattern). This GET operation provides access to resources using the &quot;Get All&quot; pattern. In this version of the API there is support for paging.
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<EemCharacteristic_Readable>> GetEEMCharacteristicsAll(int? offset= null, int? limit= null) 
        {
            var request = new RestRequest("/eemCharacteristics", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            request.AddHeader("Accept", "application/vnd.ed-fi.eemcharacteristic.sis.readable+json");
            var response = client.Execute<List<EemCharacteristic_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves resources matching values of an example resource (using the &quot;Get By Example&quot; pattern). This GET operation provides access to resources using the &quot;Get by Example&quot; search pattern.  The values of any properties of the resource that are specified will be used to return all matching results (if it exists).
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <param name="eemCharacteristicId">The EEMCharacteristic identifier.</param>
        /// <param name="name">EEMCharacteristic name.</param>
        /// <param name="label">EEMCharacteristic label.</param>
        /// <param name="description">EEMCharacteristic description.</param>
        /// <param name="steps">EEMCharacteristic steps.</param>
        /// <param name="sourceTable">EEMCharacteristic  source table.</param>
        /// <param name="sourceField">EEMCharacteristic source field.</param>
        /// <param name="valueName">EEMCharacteristic value name.</param>
        /// <param name="valueTable">EEMCharacteristic value table.</param>
        /// <param name="valueField">EEMCharacteristic value field.</param>
        /// <param name="systemName">EEMCharacteristic system name.</param>
        /// <param name="eemDataTypeDescriptor">The data type of the EEMCharacteristic</param>
        /// <param name="characteristicValueEEMDataTypeDescriptor">The data type of the CharacteristicValue.</param>
        /// <param name="id"></param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<EemCharacteristic_Readable>> GetEEMCharacteristicsAll(int? offset= null, int? limit= null, int? eemCharacteristicId= null, string name= null, string label= null, string description= null, string steps= null, string sourceTable= null, string sourceField= null, string valueName= null, string valueTable= null, string valueField= null, string systemName= null, string eemDataTypeDescriptor= null, string characteristicValueEEMDataTypeDescriptor= null, string id= null) 
        {
            var request = new RestRequest("/eemCharacteristics", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            if (eemCharacteristicId != null)
                request.AddParameter("eemCharacteristicId", eemCharacteristicId);
            if (name != null)
                request.AddParameter("name", name);
            if (label != null)
                request.AddParameter("label", label);
            if (description != null)
                request.AddParameter("description", description);
            if (steps != null)
                request.AddParameter("steps", steps);
            if (sourceTable != null)
                request.AddParameter("sourceTable", sourceTable);
            if (sourceField != null)
                request.AddParameter("sourceField", sourceField);
            if (valueName != null)
                request.AddParameter("valueName", valueName);
            if (valueTable != null)
                request.AddParameter("valueTable", valueTable);
            if (valueField != null)
                request.AddParameter("valueField", valueField);
            if (systemName != null)
                request.AddParameter("systemName", systemName);
            if (eemDataTypeDescriptor != null)
                request.AddParameter("eemDataTypeDescriptor", eemDataTypeDescriptor);
            if (characteristicValueEEMDataTypeDescriptor != null)
                request.AddParameter("characteristicValueEEMDataTypeDescriptor", characteristicValueEEMDataTypeDescriptor);
            if (id != null)
                request.AddParameter("id", id);
            request.AddHeader("Accept", "application/vnd.ed-fi.eemcharacteristic.sis.readable+json");
            var response = client.Execute<List<EemCharacteristic_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the values of the resource's natural key (using the &quot;Get By Key&quot; pattern). This GET operation provides access to resources using the &quot;Get by Key&quot; search pattern. The values of the natural key of the resource must be fully specified, and the service will return the matching result (if it exists).
        /// </summary>
        /// <param name="eemCharacteristicId">The EEMCharacteristic identifier.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<EemCharacteristic_Readable> GetEEMCharacteristicByKey(int? eemCharacteristicId, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/eemCharacteristics", Method.GET);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (eemCharacteristicId == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            if (eemCharacteristicId != null)
                request.AddParameter("eemCharacteristicId", eemCharacteristicId);
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.eemcharacteristic.sis.readable+json");
            var response = client.Execute<EemCharacteristic_Readable>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the resource's identifier (using the &quot;Get By Id&quot; pattern). This GET operation retrieves a resource by the specified resource identifier.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be retrieved.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<EemCharacteristic_Readable> GetEEMCharacteristicsById(string id, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/eemCharacteristics/{id}", Method.GET);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.eemcharacteristic.sis.readable+json");
            var response = client.Execute<EemCharacteristic_Readable>(request);

            return response;
        }
        /// <summary>
        /// Deletes an existing resource using the resource identifier. The DELETE operation is used to delete an existing resource by identifier.  If the resource doesn't exist, an error will result (the resource will not be found).
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be deleted.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the DELETE from removing a resource modified by another consumer.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse DeleteEEMCharacteristicById(string id, string IfMatch= null) 
        {
            var request = new RestRequest("/eemCharacteristics/{id}", Method.DELETE);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            var response = client.Execute(request);

            return response;
        }
        // patch operation generation was suppressed because profiles can not support patch
    }
}

