﻿using System;
using System.Collections.Generic;
using System.Linq;
using Michigan.Ods.Sdk.Helpers;
using Michigan.Ods.Sdk.Profiles.SIS.Models;
using RestSharp;
  using System.Net;
  using System.Text;
  
namespace Michigan.Ods.Sdk.Profiles.SIS.Api 
{
    public class EemEducationalEntityMastersApi 
    {
        private readonly IRestClient client;

        public EemEducationalEntityMastersApi(IRestClient client)
        {
            this.client = client;
        }
      
        /// <summary>
        /// Retrieves resources based with paging capabilities (using the &quot;Get All&quot; pattern). This GET operation provides access to resources using the &quot;Get All&quot; pattern. In this version of the API there is support for paging.
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<EemEducationalEntityMaster_Readable>> GetEEMEducationalEntityMastersAll(int? offset= null, int? limit= null) 
        {
            var request = new RestRequest("/eemEducationalEntityMasters", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            request.AddHeader("Accept", "application/vnd.ed-fi.eemeducationalentitymaster.sis.readable+json");
            var response = client.Execute<List<EemEducationalEntityMaster_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves resources matching values of an example resource (using the &quot;Get By Example&quot; pattern). This GET operation provides access to resources using the &quot;Get by Example&quot; search pattern.  The values of any properties of the resource that are specified will be used to return all matching results (if it exists).
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <param name="eemEducationalEntityMasterId">Educational Entity Master identifier from EEM system.</param>
        /// <param name="eemEntityOfficialName">The EEM official name of the Educational Entity</param>
        /// <param name="eemEntityTypeClassificationId">The EEM EntityType identifier.</param>
        /// <param name="openDate">This characteristic denotes the actual opening date of the entity or when it begins to do business. *** needs to be datetime ***</param>
        /// <param name="closeDate">This characteristic is the actual closing date of the entity or the date the entity ceased to do business. *** needs to be datetime ***</param>
        /// <param name="eemCloseReasonDescriptor">Indicates the reason why an Educational Entity was closed.</param>
        /// <param name="earlyMiddleCollegeFlag">Indicates the education organization provides both a high school education as well as up to 60 college credits.</param>
        /// <param name="eemFiscalEntityTypeDescriptor">FiscalEntityCode as indicated in EEM.</param>
        /// <param name="eemCountyId">EEM County identifier.</param>
        /// <param name="geographicEEMCountyId">EEM County identifier.</param>
        /// <param name="previousDistrictEEMEducationalEntityMasterId">Educational Entity Master identifier from EEM system.</param>
        /// <param name="eemStatusDescriptor">Denotes the EEM open / close status of the entity.</param>
        /// <param name="id"></param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<EemEducationalEntityMaster_Readable>> GetEEMEducationalEntityMastersAll(int? offset= null, int? limit= null, int? eemEducationalEntityMasterId= null, string eemEntityOfficialName= null, int? eemEntityTypeClassificationId= null, DateTime? openDate= null, DateTime? closeDate= null, string eemCloseReasonDescriptor= null, bool? earlyMiddleCollegeFlag= null, string eemFiscalEntityTypeDescriptor= null, int? eemCountyId= null, int? geographicEEMCountyId= null, int? previousDistrictEEMEducationalEntityMasterId= null, string eemStatusDescriptor= null, string id= null) 
        {
            var request = new RestRequest("/eemEducationalEntityMasters", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            if (eemEducationalEntityMasterId != null)
                request.AddParameter("eemEducationalEntityMasterId", eemEducationalEntityMasterId);
            if (eemEntityOfficialName != null)
                request.AddParameter("eemEntityOfficialName", eemEntityOfficialName);
            if (eemEntityTypeClassificationId != null)
                request.AddParameter("eemEntityTypeClassificationId", eemEntityTypeClassificationId);
            if (openDate != null)
                request.AddParameter("openDate", openDate);
            if (closeDate != null)
                request.AddParameter("closeDate", closeDate);
            if (eemCloseReasonDescriptor != null)
                request.AddParameter("eemCloseReasonDescriptor", eemCloseReasonDescriptor);
            if (earlyMiddleCollegeFlag != null)
                request.AddParameter("earlyMiddleCollegeFlag", earlyMiddleCollegeFlag);
            if (eemFiscalEntityTypeDescriptor != null)
                request.AddParameter("eemFiscalEntityTypeDescriptor", eemFiscalEntityTypeDescriptor);
            if (eemCountyId != null)
                request.AddParameter("eemCountyId", eemCountyId);
            if (geographicEEMCountyId != null)
                request.AddParameter("geographicEEMCountyId", geographicEEMCountyId);
            if (previousDistrictEEMEducationalEntityMasterId != null)
                request.AddParameter("previousDistrictEEMEducationalEntityMasterId", previousDistrictEEMEducationalEntityMasterId);
            if (eemStatusDescriptor != null)
                request.AddParameter("eemStatusDescriptor", eemStatusDescriptor);
            if (id != null)
                request.AddParameter("id", id);
            request.AddHeader("Accept", "application/vnd.ed-fi.eemeducationalentitymaster.sis.readable+json");
            var response = client.Execute<List<EemEducationalEntityMaster_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the values of the resource's natural key (using the &quot;Get By Key&quot; pattern). This GET operation provides access to resources using the &quot;Get by Key&quot; search pattern. The values of the natural key of the resource must be fully specified, and the service will return the matching result (if it exists).
        /// </summary>
        /// <param name="eemEducationalEntityMasterId">Educational Entity Master identifier from EEM system.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<EemEducationalEntityMaster_Readable> GetEEMEducationalEntityMasterByKey(int? eemEducationalEntityMasterId, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/eemEducationalEntityMasters", Method.GET);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (eemEducationalEntityMasterId == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            if (eemEducationalEntityMasterId != null)
                request.AddParameter("eemEducationalEntityMasterId", eemEducationalEntityMasterId);
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.eemeducationalentitymaster.sis.readable+json");
            var response = client.Execute<EemEducationalEntityMaster_Readable>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the resource's identifier (using the &quot;Get By Id&quot; pattern). This GET operation retrieves a resource by the specified resource identifier.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be retrieved.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<EemEducationalEntityMaster_Readable> GetEEMEducationalEntityMastersById(string id, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/eemEducationalEntityMasters/{id}", Method.GET);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.eemeducationalentitymaster.sis.readable+json");
            var response = client.Execute<EemEducationalEntityMaster_Readable>(request);

            return response;
        }
        /// <summary>
        /// Deletes an existing resource using the resource identifier. The DELETE operation is used to delete an existing resource by identifier.  If the resource doesn't exist, an error will result (the resource will not be found).
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be deleted.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the DELETE from removing a resource modified by another consumer.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse DeleteEEMEducationalEntityMasterById(string id, string IfMatch= null) 
        {
            var request = new RestRequest("/eemEducationalEntityMasters/{id}", Method.DELETE);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            var response = client.Execute(request);

            return response;
        }
        // patch operation generation was suppressed because profiles can not support patch
    }
}

