﻿using System;
using System.Collections.Generic;
using System.Linq;
using Michigan.Ods.Sdk.Helpers;
using Michigan.Ods.Sdk.Profiles.SIS.Models;
using RestSharp;
  using System.Net;
  using System.Text;
  
namespace Michigan.Ods.Sdk.Profiles.SIS.Api 
{
    public class EemEntityContactsApi 
    {
        private readonly IRestClient client;

        public EemEntityContactsApi(IRestClient client)
        {
            this.client = client;
        }
      
        /// <summary>
        /// Retrieves resources based with paging capabilities (using the &quot;Get All&quot; pattern). This GET operation provides access to resources using the &quot;Get All&quot; pattern. In this version of the API there is support for paging.
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<EemEntityContact_Readable>> GetEEMEntityContactsAll(int? offset= null, int? limit= null) 
        {
            var request = new RestRequest("/eemEntityContacts", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            request.AddHeader("Accept", "application/vnd.ed-fi.eementitycontact.sis.readable+json");
            var response = client.Execute<List<EemEntityContact_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves resources matching values of an example resource (using the &quot;Get By Example&quot; pattern). This GET operation provides access to resources using the &quot;Get by Example&quot; search pattern.  The values of any properties of the resource that are specified will be used to return all matching results (if it exists).
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <param name="eemEntityContactId">The EEMEntityContact identifier.</param>
        /// <param name="eemEducationalEntityMasterId">Educational Entity Master identifier from EEM system.</param>
        /// <param name="isLeadAdministrator">1= Yes / 0 = No</param>
        /// <param name="staffClassificationDescriptor">Represents the EEM Contact Type.</param>
        /// <param name="personalTitlePrefix">A prefix used to denote the title, degree, position, or seniority of the person.</param>
        /// <param name="firstName">A name given to an individual at birth, baptism, or during another naming ceremony, or through legal change.</param>
        /// <param name="middleName">A secondary name given to an individual at birth, baptism, or during another naming ceremony.</param>
        /// <param name="lastSurname">The name borne in common by members of a family.</param>
        /// <param name="generationCodeSuffix">An appendage, if any, used to denote an individual's generation in his family (e.g., Jr., Sr., III).</param>
        /// <param name="mailingAddressStreetNumberName">The street number and street name or post office box number of the EEM Contact's mailing address.</param>
        /// <param name="mailingAddressApartmentRoomSuiteNumber">The apartment, room, or suite number of the EEM Contact's mailing address.</param>
        /// <param name="mailingAddressCity">The name of the city in which the EEM Contact's mailing address is located.</param>
        /// <param name="mailingAddressStateAbbreviationType">The abbreviation for the state (within the United States) or outlying area in which the EEM Contact's mailing address is located.</param>
        /// <param name="mailingAddressPostalCode">The five or nine digit zip code of the EEM Contact's mailing address.</param>
        /// <param name="mailingAddresEffectiveDate">The first date the EEM Contact's mailing address is valid.</param>
        /// <param name="mailingAddressExpirationDate">The last date the EEM Contact's mailing address is valid.</param>
        /// <param name="faxNumber">The EEM Contact's fax number.</param>
        /// <param name="faxNumberExt">Extension of the EEM Contact's fax number.</param>
        /// <param name="telephoneNumber">The EEM Contact's telephone number.</param>
        /// <param name="telephoneNumberExt">Extension of the EEM Contact's telephone number.</param>
        /// <param name="electronicMailAddress">The electronic mail (e-mail) of the EEM Contact.</param>
        /// <param name="eemContactTypeDescriptor">Indicates the type of the Contact listed for the Educational Entity.</param>
        /// <param name="eemPersonalTitleDescriptor">Denotes the personal title of the Educational Entity's Contact.</param>
        /// <param name="id"></param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<EemEntityContact_Readable>> GetEEMEntityContactsAll(int? offset= null, int? limit= null, int? eemEntityContactId= null, int? eemEducationalEntityMasterId= null, bool? isLeadAdministrator= null, string staffClassificationDescriptor= null, string personalTitlePrefix= null, string firstName= null, string middleName= null, string lastSurname= null, string generationCodeSuffix= null, string mailingAddressStreetNumberName= null, string mailingAddressApartmentRoomSuiteNumber= null, string mailingAddressCity= null, string mailingAddressStateAbbreviationType= null, string mailingAddressPostalCode= null, DateTime? mailingAddresEffectiveDate= null, DateTime? mailingAddressExpirationDate= null, string faxNumber= null, string faxNumberExt= null, string telephoneNumber= null, string telephoneNumberExt= null, string electronicMailAddress= null, string eemContactTypeDescriptor= null, string eemPersonalTitleDescriptor= null, string id= null) 
        {
            var request = new RestRequest("/eemEntityContacts", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            if (eemEntityContactId != null)
                request.AddParameter("eemEntityContactId", eemEntityContactId);
            if (eemEducationalEntityMasterId != null)
                request.AddParameter("eemEducationalEntityMasterId", eemEducationalEntityMasterId);
            if (isLeadAdministrator != null)
                request.AddParameter("isLeadAdministrator", isLeadAdministrator);
            if (staffClassificationDescriptor != null)
                request.AddParameter("staffClassificationDescriptor", staffClassificationDescriptor);
            if (personalTitlePrefix != null)
                request.AddParameter("personalTitlePrefix", personalTitlePrefix);
            if (firstName != null)
                request.AddParameter("firstName", firstName);
            if (middleName != null)
                request.AddParameter("middleName", middleName);
            if (lastSurname != null)
                request.AddParameter("lastSurname", lastSurname);
            if (generationCodeSuffix != null)
                request.AddParameter("generationCodeSuffix", generationCodeSuffix);
            if (mailingAddressStreetNumberName != null)
                request.AddParameter("mailingAddressStreetNumberName", mailingAddressStreetNumberName);
            if (mailingAddressApartmentRoomSuiteNumber != null)
                request.AddParameter("mailingAddressApartmentRoomSuiteNumber", mailingAddressApartmentRoomSuiteNumber);
            if (mailingAddressCity != null)
                request.AddParameter("mailingAddressCity", mailingAddressCity);
            if (mailingAddressStateAbbreviationType != null)
                request.AddParameter("mailingAddressStateAbbreviationType", mailingAddressStateAbbreviationType);
            if (mailingAddressPostalCode != null)
                request.AddParameter("mailingAddressPostalCode", mailingAddressPostalCode);
            if (mailingAddresEffectiveDate != null)
                request.AddParameter("mailingAddresEffectiveDate", mailingAddresEffectiveDate);
            if (mailingAddressExpirationDate != null)
                request.AddParameter("mailingAddressExpirationDate", mailingAddressExpirationDate);
            if (faxNumber != null)
                request.AddParameter("faxNumber", faxNumber);
            if (faxNumberExt != null)
                request.AddParameter("faxNumberExt", faxNumberExt);
            if (telephoneNumber != null)
                request.AddParameter("telephoneNumber", telephoneNumber);
            if (telephoneNumberExt != null)
                request.AddParameter("telephoneNumberExt", telephoneNumberExt);
            if (electronicMailAddress != null)
                request.AddParameter("electronicMailAddress", electronicMailAddress);
            if (eemContactTypeDescriptor != null)
                request.AddParameter("eemContactTypeDescriptor", eemContactTypeDescriptor);
            if (eemPersonalTitleDescriptor != null)
                request.AddParameter("eemPersonalTitleDescriptor", eemPersonalTitleDescriptor);
            if (id != null)
                request.AddParameter("id", id);
            request.AddHeader("Accept", "application/vnd.ed-fi.eementitycontact.sis.readable+json");
            var response = client.Execute<List<EemEntityContact_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the values of the resource's natural key (using the &quot;Get By Key&quot; pattern). This GET operation provides access to resources using the &quot;Get by Key&quot; search pattern. The values of the natural key of the resource must be fully specified, and the service will return the matching result (if it exists).
        /// </summary>
        /// <param name="eemEntityContactId">The EEMEntityContact identifier.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<EemEntityContact_Readable> GetEEMEntityContactByKey(int? eemEntityContactId, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/eemEntityContacts", Method.GET);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (eemEntityContactId == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            if (eemEntityContactId != null)
                request.AddParameter("eemEntityContactId", eemEntityContactId);
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.eementitycontact.sis.readable+json");
            var response = client.Execute<EemEntityContact_Readable>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the resource's identifier (using the &quot;Get By Id&quot; pattern). This GET operation retrieves a resource by the specified resource identifier.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be retrieved.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<EemEntityContact_Readable> GetEEMEntityContactsById(string id, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/eemEntityContacts/{id}", Method.GET);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.eementitycontact.sis.readable+json");
            var response = client.Execute<EemEntityContact_Readable>(request);

            return response;
        }
        /// <summary>
        /// Deletes an existing resource using the resource identifier. The DELETE operation is used to delete an existing resource by identifier.  If the resource doesn't exist, an error will result (the resource will not be found).
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be deleted.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the DELETE from removing a resource modified by another consumer.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse DeleteEEMEntityContactById(string id, string IfMatch= null) 
        {
            var request = new RestRequest("/eemEntityContacts/{id}", Method.DELETE);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            var response = client.Execute(request);

            return response;
        }
        // patch operation generation was suppressed because profiles can not support patch
    }
}

