﻿using System;
using System.Collections.Generic;
using System.Linq;
using Michigan.Ods.Sdk.Helpers;
using Michigan.Ods.Sdk.Profiles.SIS.Models;
using RestSharp;
  using System.Net;
  using System.Text;
  
namespace Michigan.Ods.Sdk.Profiles.SIS.Api 
{
    public class EemSchoolYearsApi 
    {
        private readonly IRestClient client;

        public EemSchoolYearsApi(IRestClient client)
        {
            this.client = client;
        }
      
        /// <summary>
        /// Retrieves resources based with paging capabilities (using the &quot;Get All&quot; pattern). This GET operation provides access to resources using the &quot;Get All&quot; pattern. In this version of the API there is support for paging.
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<EemSchoolYear_Readable>> GetEEMSchoolYearsAll(int? offset= null, int? limit= null) 
        {
            var request = new RestRequest("/eemSchoolYears", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            request.AddHeader("Accept", "application/vnd.ed-fi.eemschoolyear.sis.readable+json");
            var response = client.Execute<List<EemSchoolYear_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves resources matching values of an example resource (using the &quot;Get By Example&quot; pattern). This GET operation provides access to resources using the &quot;Get by Example&quot; search pattern.  The values of any properties of the resource that are specified will be used to return all matching results (if it exists).
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <param name="eemSchoolYearId">Denotes the EEM SchoolYear identifier.</param>
        /// <param name="name">Denotes the EEM SchoolYear name in format YYYY-YYYY</param>
        /// <param name="currentSchoolYear">1 = Is current school year;  0 = Is not current school year;</param>
        /// <param name="schoolYearOpenDate">The EEM school year open date.</param>
        /// <param name="schoolYearEndDate">The EEM school year end date.</param>
        /// <param name="schoolYearPoPOpenDate">The EEM school year PoP open date.</param>
        /// <param name="schoolYearPoPEndDate">The EEM school year PoP end date.</param>
        /// <param name="id"></param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<EemSchoolYear_Readable>> GetEEMSchoolYearsAll(int? offset= null, int? limit= null, int? eemSchoolYearId= null, string name= null, bool? currentSchoolYear= null, DateTime? schoolYearOpenDate= null, DateTime? schoolYearEndDate= null, DateTime? schoolYearPoPOpenDate= null, DateTime? schoolYearPoPEndDate= null, string id= null) 
        {
            var request = new RestRequest("/eemSchoolYears", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            if (eemSchoolYearId != null)
                request.AddParameter("eemSchoolYearId", eemSchoolYearId);
            if (name != null)
                request.AddParameter("name", name);
            if (currentSchoolYear != null)
                request.AddParameter("currentSchoolYear", currentSchoolYear);
            if (schoolYearOpenDate != null)
                request.AddParameter("schoolYearOpenDate", schoolYearOpenDate);
            if (schoolYearEndDate != null)
                request.AddParameter("schoolYearEndDate", schoolYearEndDate);
            if (schoolYearPoPOpenDate != null)
                request.AddParameter("schoolYearPoPOpenDate", schoolYearPoPOpenDate);
            if (schoolYearPoPEndDate != null)
                request.AddParameter("schoolYearPoPEndDate", schoolYearPoPEndDate);
            if (id != null)
                request.AddParameter("id", id);
            request.AddHeader("Accept", "application/vnd.ed-fi.eemschoolyear.sis.readable+json");
            var response = client.Execute<List<EemSchoolYear_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the values of the resource's natural key (using the &quot;Get By Key&quot; pattern). This GET operation provides access to resources using the &quot;Get by Key&quot; search pattern. The values of the natural key of the resource must be fully specified, and the service will return the matching result (if it exists).
        /// </summary>
        /// <param name="eemSchoolYearId">Denotes the EEM SchoolYear identifier.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<EemSchoolYear_Readable> GetEEMSchoolYearByKey(int? eemSchoolYearId, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/eemSchoolYears", Method.GET);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (eemSchoolYearId == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            if (eemSchoolYearId != null)
                request.AddParameter("eemSchoolYearId", eemSchoolYearId);
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.eemschoolyear.sis.readable+json");
            var response = client.Execute<EemSchoolYear_Readable>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the resource's identifier (using the &quot;Get By Id&quot; pattern). This GET operation retrieves a resource by the specified resource identifier.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be retrieved.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<EemSchoolYear_Readable> GetEEMSchoolYearsById(string id, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/eemSchoolYears/{id}", Method.GET);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.eemschoolyear.sis.readable+json");
            var response = client.Execute<EemSchoolYear_Readable>(request);

            return response;
        }
        /// <summary>
        /// Deletes an existing resource using the resource identifier. The DELETE operation is used to delete an existing resource by identifier.  If the resource doesn't exist, an error will result (the resource will not be found).
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be deleted.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the DELETE from removing a resource modified by another consumer.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse DeleteEEMSchoolYearById(string id, string IfMatch= null) 
        {
            var request = new RestRequest("/eemSchoolYears/{id}", Method.DELETE);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            var response = client.Execute(request);

            return response;
        }
        // patch operation generation was suppressed because profiles can not support patch
    }
}

