﻿using System;
using System.Collections.Generic;
using System.Linq;
using Michigan.Ods.Sdk.Helpers;
using Michigan.Ods.Sdk.Profiles.SIS.Models;
using RestSharp;
  using System.Net;
  using System.Text;
  
namespace Michigan.Ods.Sdk.Profiles.SIS.Api 
{
    public class StaffREPCredentialsApi 
    {
        private readonly IRestClient client;

        public StaffREPCredentialsApi(IRestClient client)
        {
            this.client = client;
        }
      
        /// <summary>
        /// Retrieves resources based with paging capabilities (using the &quot;Get All&quot; pattern). This GET operation provides access to resources using the &quot;Get All&quot; pattern. In this version of the API there is support for paging.
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<StaffREPCredential_Readable>> GetStaffREPCredentialsAll(int? offset= null, int? limit= null) 
        {
            var request = new RestRequest("/staffREPCredentials", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            request.AddHeader("Accept", "application/vnd.ed-fi.staffrepcredential.sis.readable+json");
            var response = client.Execute<List<StaffREPCredential_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves resources matching values of an example resource (using the &quot;Get By Example&quot; pattern). This GET operation provides access to resources using the &quot;Get by Example&quot; search pattern.  The values of any properties of the resource that are specified will be used to return all matching results (if it exists).
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <param name="staffUniqueId">A unique alpha-numeric code assigned to a staff.</param>
        /// <param name="credentialFieldDescriptor">The field of certification for the certificate (e.g., Mathematics, Music)</param>
        /// <param name="credentialType">An indication of the category of credential an individual holds.</param>
        /// <param name="levelDescriptor">A unique identifier used as Primary Key, not derived from business logic, when acting as Foreign Key, references the parent table.</param>
        /// <param name="teachingCredentialDescriptor">A unique identifier used as Primary Key, not derived from business logic, when acting as Foreign Key, references the parent table.</param>
        /// <param name="credentialIssuanceDate">The month, day, and year on which an active credential was issued to an individual.</param>
        /// <param name="repTypeOfCredentialDescriptor">(MI EXT) A unique identifier used as Primary Key, not derived from business logic, when acting as Foreign Key, references the parent table.</param>
        /// <param name="professionalCertificateOrLicenseNumber">The number issued by the credentialing/licensing agency. </param>
        /// <param name="credentialExpirationDate"></param>
        /// <param name="teachingCredentialBasisType"></param>
        /// <param name="stateOfIssueStateAbbreviationType"></param>
        /// <param name="id"></param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<StaffREPCredential_Readable>> GetStaffREPCredentialsAll(int? offset= null, int? limit= null, string staffUniqueId= null, string credentialFieldDescriptor= null, string credentialType= null, string levelDescriptor= null, string teachingCredentialDescriptor= null, DateTime? credentialIssuanceDate= null, string repTypeOfCredentialDescriptor= null, string professionalCertificateOrLicenseNumber= null, DateTime? credentialExpirationDate= null, string teachingCredentialBasisType= null, string stateOfIssueStateAbbreviationType= null, string id= null) 
        {
            var request = new RestRequest("/staffREPCredentials", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            if (staffUniqueId != null)
                request.AddParameter("staffUniqueId", staffUniqueId);
            if (credentialFieldDescriptor != null)
                request.AddParameter("credentialFieldDescriptor", credentialFieldDescriptor);
            if (credentialType != null)
                request.AddParameter("credentialType", credentialType);
            if (levelDescriptor != null)
                request.AddParameter("levelDescriptor", levelDescriptor);
            if (teachingCredentialDescriptor != null)
                request.AddParameter("teachingCredentialDescriptor", teachingCredentialDescriptor);
            if (credentialIssuanceDate != null)
                request.AddParameter("credentialIssuanceDate", credentialIssuanceDate);
            if (repTypeOfCredentialDescriptor != null)
                request.AddParameter("repTypeOfCredentialDescriptor", repTypeOfCredentialDescriptor);
            if (professionalCertificateOrLicenseNumber != null)
                request.AddParameter("professionalCertificateOrLicenseNumber", professionalCertificateOrLicenseNumber);
            if (credentialExpirationDate != null)
                request.AddParameter("credentialExpirationDate", credentialExpirationDate);
            if (teachingCredentialBasisType != null)
                request.AddParameter("teachingCredentialBasisType", teachingCredentialBasisType);
            if (stateOfIssueStateAbbreviationType != null)
                request.AddParameter("stateOfIssueStateAbbreviationType", stateOfIssueStateAbbreviationType);
            if (id != null)
                request.AddParameter("id", id);
            request.AddHeader("Accept", "application/vnd.ed-fi.staffrepcredential.sis.readable+json");
            var response = client.Execute<List<StaffREPCredential_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the values of the resource's natural key (using the &quot;Get By Key&quot; pattern). This GET operation provides access to resources using the &quot;Get by Key&quot; search pattern. The values of the natural key of the resource must be fully specified, and the service will return the matching result (if it exists).
        /// </summary>
        /// <param name="staffUniqueId">A unique alpha-numeric code assigned to a staff.</param>
        /// <param name="credentialFieldDescriptor">The field of certification for the certificate (e.g., Mathematics, Music)</param>
        /// <param name="credentialType">An indication of the category of credential an individual holds.</param>
        /// <param name="levelDescriptor">A unique identifier used as Primary Key, not derived from business logic, when acting as Foreign Key, references the parent table.</param>
        /// <param name="teachingCredentialDescriptor">A unique identifier used as Primary Key, not derived from business logic, when acting as Foreign Key, references the parent table.</param>
        /// <param name="credentialIssuanceDate">The month, day, and year on which an active credential was issued to an individual.</param>
        /// <param name="repTypeOfCredentialDescriptor">(MI EXT) A unique identifier used as Primary Key, not derived from business logic, when acting as Foreign Key, references the parent table.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<StaffREPCredential_Readable> GetStaffREPCredentialByKey(string staffUniqueId, string credentialFieldDescriptor, string credentialType, string levelDescriptor, string teachingCredentialDescriptor, DateTime? credentialIssuanceDate, string repTypeOfCredentialDescriptor, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/staffREPCredentials", Method.GET);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (staffUniqueId == null || credentialFieldDescriptor == null || credentialType == null || levelDescriptor == null || teachingCredentialDescriptor == null || credentialIssuanceDate == null || repTypeOfCredentialDescriptor == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            if (staffUniqueId != null)
                request.AddParameter("staffUniqueId", staffUniqueId);
            if (credentialFieldDescriptor != null)
                request.AddParameter("credentialFieldDescriptor", credentialFieldDescriptor);
            if (credentialType != null)
                request.AddParameter("credentialType", credentialType);
            if (levelDescriptor != null)
                request.AddParameter("levelDescriptor", levelDescriptor);
            if (teachingCredentialDescriptor != null)
                request.AddParameter("teachingCredentialDescriptor", teachingCredentialDescriptor);
            if (credentialIssuanceDate != null)
                request.AddParameter("credentialIssuanceDate", credentialIssuanceDate);
            if (repTypeOfCredentialDescriptor != null)
                request.AddParameter("repTypeOfCredentialDescriptor", repTypeOfCredentialDescriptor);
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.staffrepcredential.sis.readable+json");
            var response = client.Execute<StaffREPCredential_Readable>(request);

            return response;
        }
        /// <summary>
        /// Creates or updates resources based on the natural key values of the supplied resource. The POST operation can be used to create or update resources. In database terms, this is often referred to as an &quot;upsert&quot; operation (insert + update).  Clients should NOT include the resource &quot;id&quot; in the JSON body because it will result in an error (you must use a PUT operation to update a resource by &quot;id&quot;). The web service will identify whether the resource already exists based on the natural key values provided, and update or create the resource appropriately.
        /// </summary>
        /// <param name="body">The JSON representation of the &quot;staffREPCredential&quot; resource to be created or updated.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse PostStaffREPCredentials(StaffREPCredential_Writable body) 
        {
            var request = new RestRequest("/staffREPCredentials", Method.POST);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (body == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddBody(body);
            request.Parameters.First(param => param.Type == ParameterType.RequestBody).Name = "application/vnd.ed-fi.staffrepcredential.sis.writable+json";
            var response = client.Execute(request);

            var location = response.Headers.FirstOrDefault(x => x.Name == "Location");

            if (location != null && !string.IsNullOrWhiteSpace(location.Value.ToString()))
                body.id = location.Value.ToString().Split('/').Last();
            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the resource's identifier (using the &quot;Get By Id&quot; pattern). This GET operation retrieves a resource by the specified resource identifier.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be retrieved.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<StaffREPCredential_Readable> GetStaffREPCredentialsById(string id, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/staffREPCredentials/{id}", Method.GET);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.staffrepcredential.sis.readable+json");
            var response = client.Execute<StaffREPCredential_Readable>(request);

            return response;
        }
        /// <summary>
        /// Updates or creates a resource based on the resource identifier. The PUT operation is used to update or create a resource by identifier.  If the resource doesn't exist, the resource will be created using that identifier.  Additionally, natural key values cannot be changed using this operation, and will not be modified in the database.  If the resource &quot;id&quot; is provided in the JSON body, it will be ignored as well.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be updated.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the PUT from updating a resource modified by another consumer.</param>
        /// <param name="body">The JSON representation of the &quot;staffREPCredential&quot; resource to be updated.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse PutStaffREPCredential(string id, string IfMatch, StaffREPCredential_Writable body) 
        {
            var request = new RestRequest("/staffREPCredentials/{id}", Method.PUT);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null || body == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            request.AddBody(body);
            request.Parameters.First(param => param.Type == ParameterType.RequestBody).Name = "application/vnd.ed-fi.staffrepcredential.sis.writable+json";
            var response = client.Execute(request);

            var location = response.Headers.FirstOrDefault(x => x.Name == "Location");

            if (location != null && !string.IsNullOrWhiteSpace(location.Value.ToString()))
                body.id = location.Value.ToString().Split('/').Last();
            return response;
        }
        /// <summary>
        /// Deletes an existing resource using the resource identifier. The DELETE operation is used to delete an existing resource by identifier.  If the resource doesn't exist, an error will result (the resource will not be found).
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be deleted.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the DELETE from removing a resource modified by another consumer.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse DeleteStaffREPCredentialById(string id, string IfMatch= null) 
        {
            var request = new RestRequest("/staffREPCredentials/{id}", Method.DELETE);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            var response = client.Execute(request);

            return response;
        }
        // patch operation generation was suppressed because profiles can not support patch
    }
}

