﻿using System;
using System.Collections.Generic;
using System.Linq;
using Michigan.Ods.Sdk.Helpers;
using Michigan.Ods.Sdk.Profiles.SIS.Models;
using RestSharp;
  using System.Net;
  using System.Text;
  
namespace Michigan.Ods.Sdk.Profiles.SIS.Api 
{
    public class StudentEarlyLearningProgramAssociationsApi 
    {
        private readonly IRestClient client;

        public StudentEarlyLearningProgramAssociationsApi(IRestClient client)
        {
            this.client = client;
        }
      
        /// <summary>
        /// Retrieves resources based with paging capabilities (using the &quot;Get All&quot; pattern). This GET operation provides access to resources using the &quot;Get All&quot; pattern. In this version of the API there is support for paging.
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<StudentEarlyLearningProgramAssociation_Readable>> GetStudentEarlyLearningProgramAssociationsAll(int? offset= null, int? limit= null) 
        {
            var request = new RestRequest("/studentEarlyLearningProgramAssociations", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            request.AddHeader("Accept", "application/vnd.ed-fi.studentearlylearningprogramassociation.sis.readable+json");
            var response = client.Execute<List<StudentEarlyLearningProgramAssociation_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves resources matching values of an example resource (using the &quot;Get By Example&quot; pattern). This GET operation provides access to resources using the &quot;Get by Example&quot; search pattern.  The values of any properties of the resource that are specified will be used to return all matching results (if it exists).
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <param name="beginDate">The month, day, and year on which the Student first received services.</param>
        /// <param name="educationOrganizationId">The identifier assigned to an education agency by the State Education Agency (SEA).  Also known as the State LEA ID.</param>
        /// <param name="programEducationOrganizationId">The identifier assigned to an education agency by the State Education Agency (SEA).  Also known as the State LEA ID.</param>
        /// <param name="programName">The formal name of the Program of instruction, training, services, or benefits available through federal, state, or local agencies.</param>
        /// <param name="programType">The type of program.</param>
        /// <param name="studentUniqueId">A unique alpha-numeric code assigned to a student.</param>
        /// <param name="deliveryMethodDescriptor">The primary location where the student attends the reported program or receives early childhood services.</param>
        /// <param name="deliveryScheduleDescriptor">The primary schedule followed by the student for this program or service.</param>
        /// <param name="federalPovertyLevelDescriptor">The Federal Poverty Level (FPL) quintile that a child belongs to. </param>
        /// <param name="providerLicenseNumber">The license number assigned to the location a child receives early childhood services. Licensed providers are assigned an 11-digit code (2 letters, 9 numbers) by the Michigan Department of Licensing and Regulatory Affairs. Tribal programs not licensed by the State are assigned a 14-digit code (7 letters, 7 numbers) by the Early Childhood Investment Corporation.</param>
        /// <param name="ecComment">A field to provide users with the option of adding a comment to distinguish a child for their own records. This field is optional and is not required to be completed.</param>
        /// <param name="workingParents">1 = parent(s) are working and unavailable to care for the child during program hours. This could include a parent attending school or working a night shift requiring sleep during the day.  0 = the parents are not working and available to provide care during program hours.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<StudentEarlyLearningProgramAssociation_Readable>> GetStudentEarlyLearningProgramAssociationsAll(int? offset= null, int? limit= null, DateTime? beginDate= null, int? educationOrganizationId= null, int? programEducationOrganizationId= null, string programName= null, string programType= null, string studentUniqueId= null, string deliveryMethodDescriptor= null, string deliveryScheduleDescriptor= null, string federalPovertyLevelDescriptor= null, string providerLicenseNumber= null, string ecComment= null, bool? workingParents= null) 
        {
            var request = new RestRequest("/studentEarlyLearningProgramAssociations", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            if (beginDate != null)
                request.AddParameter("beginDate", beginDate);
            if (educationOrganizationId != null)
                request.AddParameter("educationOrganizationId", educationOrganizationId);
            if (programEducationOrganizationId != null)
                request.AddParameter("programEducationOrganizationId", programEducationOrganizationId);
            if (programName != null)
                request.AddParameter("programName", programName);
            if (programType != null)
                request.AddParameter("programType", programType);
            if (studentUniqueId != null)
                request.AddParameter("studentUniqueId", studentUniqueId);
            if (deliveryMethodDescriptor != null)
                request.AddParameter("deliveryMethodDescriptor", deliveryMethodDescriptor);
            if (deliveryScheduleDescriptor != null)
                request.AddParameter("deliveryScheduleDescriptor", deliveryScheduleDescriptor);
            if (federalPovertyLevelDescriptor != null)
                request.AddParameter("federalPovertyLevelDescriptor", federalPovertyLevelDescriptor);
            if (providerLicenseNumber != null)
                request.AddParameter("providerLicenseNumber", providerLicenseNumber);
            if (ecComment != null)
                request.AddParameter("ecComment", ecComment);
            if (workingParents != null)
                request.AddParameter("workingParents", workingParents);
            request.AddHeader("Accept", "application/vnd.ed-fi.studentearlylearningprogramassociation.sis.readable+json");
            var response = client.Execute<List<StudentEarlyLearningProgramAssociation_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the values of the resource's natural key (using the &quot;Get By Key&quot; pattern). This GET operation provides access to resources using the &quot;Get by Key&quot; search pattern. The values of the natural key of the resource must be fully specified, and the service will return the matching result (if it exists).
        /// </summary>
        /// <param name="beginDate">The month, day, and year on which the Student first received services.</param>
        /// <param name="educationOrganizationId">The identifier assigned to an education agency by the State Education Agency (SEA).  Also known as the State LEA ID.</param>
        /// <param name="programEducationOrganizationId">The identifier assigned to an education agency by the State Education Agency (SEA).  Also known as the State LEA ID.</param>
        /// <param name="programName">The formal name of the Program of instruction, training, services, or benefits available through federal, state, or local agencies.</param>
        /// <param name="programType">The type of program.</param>
        /// <param name="studentUniqueId">A unique alpha-numeric code assigned to a student.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<StudentEarlyLearningProgramAssociation_Readable> GetStudentEarlyLearningProgramAssociationByKey(DateTime? beginDate, int? educationOrganizationId, int? programEducationOrganizationId, string programName, string programType, string studentUniqueId, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/studentEarlyLearningProgramAssociations", Method.GET);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (beginDate == null || educationOrganizationId == null || programEducationOrganizationId == null || programName == null || programType == null || studentUniqueId == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            if (beginDate != null)
                request.AddParameter("beginDate", beginDate);
            if (educationOrganizationId != null)
                request.AddParameter("educationOrganizationId", educationOrganizationId);
            if (programEducationOrganizationId != null)
                request.AddParameter("programEducationOrganizationId", programEducationOrganizationId);
            if (programName != null)
                request.AddParameter("programName", programName);
            if (programType != null)
                request.AddParameter("programType", programType);
            if (studentUniqueId != null)
                request.AddParameter("studentUniqueId", studentUniqueId);
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.studentearlylearningprogramassociation.sis.readable+json");
            var response = client.Execute<StudentEarlyLearningProgramAssociation_Readable>(request);

            return response;
        }
        /// <summary>
        /// Creates or updates resources based on the natural key values of the supplied resource. The POST operation can be used to create or update resources. In database terms, this is often referred to as an &quot;upsert&quot; operation (insert + update).  Clients should NOT include the resource &quot;id&quot; in the JSON body because it will result in an error (you must use a PUT operation to update a resource by &quot;id&quot;). The web service will identify whether the resource already exists based on the natural key values provided, and update or create the resource appropriately.
        /// </summary>
        /// <param name="body">The JSON representation of the &quot;studentEarlyLearningProgramAssociation&quot; resource to be created or updated.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse PostStudentEarlyLearningProgramAssociations(StudentEarlyLearningProgramAssociation_Writable body) 
        {
            var request = new RestRequest("/studentEarlyLearningProgramAssociations", Method.POST);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (body == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddBody(body);
            request.Parameters.First(param => param.Type == ParameterType.RequestBody).Name = "application/vnd.ed-fi.studentearlylearningprogramassociation.sis.writable+json";
            var response = client.Execute(request);

            var location = response.Headers.FirstOrDefault(x => x.Name == "Location");

            if (location != null && !string.IsNullOrWhiteSpace(location.Value.ToString()))
                body.id = location.Value.ToString().Split('/').Last();
            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the resource's identifier (using the &quot;Get By Id&quot; pattern). This GET operation retrieves a resource by the specified resource identifier.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be retrieved.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<StudentEarlyLearningProgramAssociation_Readable> GetStudentEarlyLearningProgramAssociationsById(string id, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/studentEarlyLearningProgramAssociations/{id}", Method.GET);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.studentearlylearningprogramassociation.sis.readable+json");
            var response = client.Execute<StudentEarlyLearningProgramAssociation_Readable>(request);

            return response;
        }
        /// <summary>
        /// Updates or creates a resource based on the resource identifier. The PUT operation is used to update or create a resource by identifier.  If the resource doesn't exist, the resource will be created using that identifier.  Additionally, natural key values cannot be changed using this operation, and will not be modified in the database.  If the resource &quot;id&quot; is provided in the JSON body, it will be ignored as well.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be updated.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the PUT from updating a resource modified by another consumer.</param>
        /// <param name="body">The JSON representation of the &quot;studentEarlyLearningProgramAssociation&quot; resource to be updated.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse PutStudentEarlyLearningProgramAssociation(string id, string IfMatch, StudentEarlyLearningProgramAssociation_Writable body) 
        {
            var request = new RestRequest("/studentEarlyLearningProgramAssociations/{id}", Method.PUT);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null || body == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            request.AddBody(body);
            request.Parameters.First(param => param.Type == ParameterType.RequestBody).Name = "application/vnd.ed-fi.studentearlylearningprogramassociation.sis.writable+json";
            var response = client.Execute(request);

            var location = response.Headers.FirstOrDefault(x => x.Name == "Location");

            if (location != null && !string.IsNullOrWhiteSpace(location.Value.ToString()))
                body.id = location.Value.ToString().Split('/').Last();
            return response;
        }
        /// <summary>
        /// Deletes an existing resource using the resource identifier. The DELETE operation is used to delete an existing resource by identifier.  If the resource doesn't exist, an error will result (the resource will not be found).
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be deleted.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the DELETE from removing a resource modified by another consumer.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse DeleteStudentEarlyLearningProgramAssociationById(string id, string IfMatch= null) 
        {
            var request = new RestRequest("/studentEarlyLearningProgramAssociations/{id}", Method.DELETE);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            var response = client.Execute(request);

            return response;
        }
        // patch operation generation was suppressed because profiles can not support patch
    }
}

