﻿using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace Michigan.Ods.Sdk.Profiles.SIS.Models 
{
    public class BalanceSheet_Writable 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// A reference to the related EducationOrganization resource.
        /// </summary>
        public EducationOrganizationReference educationOrganizationReference { get; set; }

        /// <summary>
        /// The basic account identifier for recording transactions.
        /// </summary>
        public string majorClassDescriptor { get; set; }

        /// <summary>
        /// Denotes the fiscal year for which the balance sheet is submitted.
        /// </summary>
        public int? fiscalYear { get; set; }

        /// <summary>
        /// The independent fisal and accounting entity for balance sheet transaction.
        /// </summary>
        public string fundCodeDescriptor { get; set; }

        /// <summary>
        /// The code used to further define/distinguish between sources (four positions). Field is included in the Michigan School Accounting Manual Chart of Accounts but is an optional field in FID collection. Provided should district's choose to submit data from the districti's accounting system if this field is used.
        /// </summary>
        public string suffixCode { get; set; }

        /// <summary>
        /// An optional field. Is included in the Michigan School Accounting Manual Chart of Accounts but is not required for the FID collection.
        /// </summary>
        public string optional { get; set; }

        /// <summary>
        /// Ending balance for the fund code / major class code submitted.
        /// </summary>
        public double? endingBalance { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

