﻿using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace Michigan.Ods.Sdk.Profiles.SIS.Models 
{
    public class Course_Writable 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// A reference to the related EducationOrganization resource.
        /// </summary>
        public EducationOrganizationReference educationOrganizationReference { get; set; }

        /// <summary>
        /// A unique alphanumeric code assigned to a course.
        /// </summary>
        public string code { get; set; }

        /// <summary>
        /// The descriptive name given to a course of study offered in a school or other institution or organization. In departmentalized classes at the elementary, secondary, and postsecondary levels (and for staff development activities), this refers to the name by which a course is identified (e.g., American History, English III). For elementary and other non-departmentalized classes, it refers to any portion of the instruction for which a grade or report is assigned (e.g., reading, composition, spelling, and language arts).
        /// </summary>
        public string title { get; set; }

        /// <summary>
        /// The number of parts identified for a course.
        /// </summary>
        public int? numberOfParts { get; set; }

        /// <summary>
        /// The intended major subject area of the course.
        /// </summary>
        public string academicSubjectDescriptor { get; set; }

        /// <summary>
        /// A description of the content standards and goals covered in the course. Reference may be made to state or national content standards.
        /// </summary>
        public string description { get; set; }

        /// <summary>
        /// The actual or estimated number of clock minutes required for class completion.  This number is especially important for career and technical education classes and may represent (in minutes) the clock hour requirement of the class.
        /// </summary>
        public int? timeRequiredForCompletion { get; set; }

        /// <summary>
        /// Date the course was adopted by the education agency.
        /// </summary>
        public DateTime? dateCourseAdopted { get; set; }

        /// <summary>
        /// An indication that this course may satisfy high school graduation requirements in the course's subject area.
        /// </summary>
        public bool? highSchoolCourseRequirement { get; set; }

        /// <summary>
        /// An indicator of whether or not the course being described is included in the computation of the student's Grade Point Average, and if so, if it is weighted differently from regular courses.
        /// </summary>
        public string gpaApplicabilityType { get; set; }

        /// <summary>
        /// Specifies whether the course was defined by the SEA, LEA, School, or national organization.
        /// </summary>
        public string definedByType { get; set; }

        /// <summary>
        /// The value of credits or units of value awarded for the completion of a course.
        /// </summary>
        public double? minimumAvailableCredits { get; set; }

        /// <summary>
        /// The type of credits or units of value awarded for the completion of a course.
        /// </summary>
        public string minimumAvailableCreditType { get; set; }

        /// <summary>
        /// Conversion factor that when multiplied by the number of credits is equivalent to Carnegie units.
        /// </summary>
        public double? minimumAvailableCreditConversion { get; set; }

        /// <summary>
        /// The value of credits or units of value awarded for the completion of a course.
        /// </summary>
        public double? maximumAvailableCredits { get; set; }

        /// <summary>
        /// The type of credits or units of value awarded for the completion of a course.
        /// </summary>
        public string maximumAvailableCreditType { get; set; }

        /// <summary>
        /// Conversion factor that when multiplied by the number of credits is equivalent to Carnegie units.
        /// </summary>
        public double? maximumAvailableCreditConversion { get; set; }

        /// <summary>
        /// Indicates the career cluster or pathway the course is associated with as part of a CTE curriculum.
        /// </summary>
        public string careerPathwayType { get; set; }

        /// <summary>
        /// (MI EXT) Indicates the level and rigor of the instruction provided throughout the reported course. Code 07 is to be used for college instructed courses for which the student will receive high school credit. The student may be participating in an Early/Middle College program or a dual enrollment program.
        /// </summary>
        public string typeLevelAndRigorDescriptor { get; set; }

        /// <summary>
        /// (MI EXT) Indicates status (OneRoster courses.status) of the Course.
        /// </summary>
        public string statusDescriptor { get; set; }

        /// <summary>
        /// (MI EXT) This course is eligible for the 64b dual enrollment funding incentive.
        /// </summary>
        public bool? eligible64bCourse { get; set; }

        /// <summary>
        /// An unordered collection of courseCompetencyLevels.  The competency levels defined to rate the student for the course.
        /// </summary>
        public List<CourseCompetencyLevel_Writable> competencyLevels { get; set; }

        /// <summary>
        /// An unordered collection of courseIdentificationCodes.  The code that identifies the organization of subject matter and related learning experiences provided for the instruction of students.
        /// </summary>
        public List<CourseIdentificationCode_Writable> identificationCodes { get; set; }

        /// <summary>
        /// An unordered collection of courseLearningObjectives.  Learning Objectives to be mastered in the course.
        /// </summary>
        public List<CourseLearningObjective_Writable> learningObjectives { get; set; }

        /// <summary>
        /// An unordered collection of courseLearningStandards.  Learning Standard(s) to be taught by the course.
        /// </summary>
        public List<CourseLearningStandard_Writable> learningStandards { get; set; }

        /// <summary>
        /// An unordered collection of courseLevelCharacteristics.  The type of specific program or designation with which the course is associated (e.g., AP, IB, Dual Credit, CTE).
        /// </summary>
        public List<CourseLevelCharacteristic_Writable> levelCharacteristics { get; set; }

        /// <summary>
        /// An unordered collection of courseOfferedGradeLevels.  The grade levels in which the course is offered.
        /// </summary>
        public List<CourseOfferedGradeLevel_Writable> offeredGradeLevels { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

