﻿using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace Michigan.Ods.Sdk.Profiles.SIS.Models 
{
    public class EemEntityContact_Readable 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// A reference to the related EEMEducationalEntityMaster resource.
        /// </summary>
        public EemEducationalEntityMasterReference eemEducationalEntityMasterReference { get; set; }

        /// <summary>
        /// The EEMEntityContact identifier.
        /// </summary>
        public int? eemEntityContactId { get; set; }

        /// <summary>
        /// 1= Yes / 0 = No
        /// </summary>
        public bool? isLeadAdministrator { get; set; }

        /// <summary>
        /// Represents the EEM Contact Type.
        /// </summary>
        public string staffClassificationDescriptor { get; set; }

        /// <summary>
        /// A prefix used to denote the title, degree, position, or seniority of the person.
        /// </summary>
        public string personalTitlePrefix { get; set; }

        /// <summary>
        /// A name given to an individual at birth, baptism, or during another naming ceremony, or through legal change.
        /// </summary>
        public string firstName { get; set; }

        /// <summary>
        /// A secondary name given to an individual at birth, baptism, or during another naming ceremony.
        /// </summary>
        public string middleName { get; set; }

        /// <summary>
        /// The name borne in common by members of a family.
        /// </summary>
        public string lastSurname { get; set; }

        /// <summary>
        /// An appendage, if any, used to denote an individual's generation in his family (e.g., Jr., Sr., III).
        /// </summary>
        public string generationCodeSuffix { get; set; }

        /// <summary>
        /// The street number and street name or post office box number of the EEM Contact's mailing address.
        /// </summary>
        public string mailingAddressStreetNumberName { get; set; }

        /// <summary>
        /// The apartment, room, or suite number of the EEM Contact's mailing address.
        /// </summary>
        public string mailingAddressApartmentRoomSuiteNumber { get; set; }

        /// <summary>
        /// The name of the city in which the EEM Contact's mailing address is located.
        /// </summary>
        public string mailingAddressCity { get; set; }

        /// <summary>
        /// The abbreviation for the state (within the United States) or outlying area in which the EEM Contact's mailing address is located.
        /// </summary>
        public string mailingAddressStateAbbreviationType { get; set; }

        /// <summary>
        /// The five or nine digit zip code of the EEM Contact's mailing address.
        /// </summary>
        public string mailingAddressPostalCode { get; set; }

        /// <summary>
        /// The first date the EEM Contact's mailing address is valid.
        /// </summary>
        public DateTime? mailingAddresEffectiveDate { get; set; }

        /// <summary>
        /// The last date the EEM Contact's mailing address is valid.
        /// </summary>
        public DateTime? mailingAddressExpirationDate { get; set; }

        /// <summary>
        /// The EEM Contact's fax number.
        /// </summary>
        public string faxNumber { get; set; }

        /// <summary>
        /// Extension of the EEM Contact's fax number.
        /// </summary>
        public string faxNumberExt { get; set; }

        /// <summary>
        /// The EEM Contact's telephone number.
        /// </summary>
        public string telephoneNumber { get; set; }

        /// <summary>
        /// Extension of the EEM Contact's telephone number.
        /// </summary>
        public string telephoneNumberExt { get; set; }

        /// <summary>
        /// The electronic mail (e-mail) of the EEM Contact.
        /// </summary>
        public string electronicMailAddress { get; set; }

        /// <summary>
        /// Indicates the type of the Contact listed for the Educational Entity.
        /// </summary>
        public string eemContactTypeDescriptor { get; set; }

        /// <summary>
        /// Denotes the personal title of the Educational Entity's Contact.
        /// </summary>
        public string eemPersonalTitleDescriptor { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

