﻿using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace Michigan.Ods.Sdk.Profiles.SIS.Models 
{
    public class Intervention_Readable 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// A reference to the related EducationOrganization resource.
        /// </summary>
        public EducationOrganizationReference educationOrganizationReference { get; set; }

        /// <summary>
        /// A unique number or alphanumeric code assigned to an intervention.
        /// </summary>
        public string identificationCode { get; set; }

        /// <summary>
        /// The way in which an intervention is used: curriculum, supplement, or practice.
        /// </summary>
        public string classType { get; set; }

        /// <summary>
        /// The start date for the intervention implementation.
        /// </summary>
        public DateTime? beginDate { get; set; }

        /// <summary>
        /// The end date for the intervention implementation.
        /// </summary>
        public DateTime? endDate { get; set; }

        /// <summary>
        /// (MI EXT) Name of the Contact for this Intervention.
        /// </summary>
        public string contactName { get; set; }

        /// <summary>
        /// (MI EXT) Electronic mail (e-mail) of the Contact for this Intervention.
        /// </summary>
        public string contactElectronicMailAddress { get; set; }

        /// <summary>
        /// (MI EXT) Telephone number of the Contact for this Intervention.
        /// </summary>
        public string contactTelephoneNumber { get; set; }

        /// <summary>
        /// (MI EXT) 0="No" 1="Yes" NULL="Unknown"
        /// </summary>
        public bool? hasCost { get; set; }

        /// <summary>
        /// (MI EXT) A statement that provides information regarding the cost of this Intervention.
        /// </summary>
        public string costStatement { get; set; }

        /// <summary>
        /// (MI EXT) Indicates if this Intervention has been deleted. 0="No" 1="Yes" NULL="Unknown"
        /// </summary>
        public bool? deleted { get; set; }

        /// <summary>
        /// (MI EXT) A description of this Intervention.
        /// </summary>
        public string description { get; set; }

        /// <summary>
        /// (MI EXT) 0="No" 1="Yes" NULL="Unknown"
        /// </summary>
        public bool? hasDuration { get; set; }

        /// <summary>
        /// (MI EXT) Duration length.
        /// </summary>
        public int? durationLength { get; set; }

        /// <summary>
        /// (MI EXT) Duration period.
        /// </summary>
        public string durationPeriod { get; set; }

        /// <summary>
        /// (MI EXT) 0="No" 1="Yes" NULL="Unknown"
        /// </summary>
        public bool? hasEligibility { get; set; }

        /// <summary>
        /// (MI EXT) A statement that provides information regarding the eligibility of this Intervention.
        /// </summary>
        public string eligibilityStatement { get; set; }

        /// <summary>
        /// (MI EXT) 0="No" 1="Yes" NULL="Unknown"
        /// </summary>
        public bool? locationReferral { get; set; }

        /// <summary>
        /// (MI EXT) 0="No" 1="Yes" NULL="Unknown"
        /// </summary>
        public bool? parentPermissionRequired { get; set; }

        /// <summary>
        /// (MI EXT) A unique identifier used as Primary Key, not derived from business logic, when acting as Foreign Key, references the parent table.
        /// </summary>
        public string periodType { get; set; }

        /// <summary>
        /// (MI EXT) The name of this Intervention.
        /// </summary>
        public string name { get; set; }

        /// <summary>
        /// (MI EXT) Indicates the source where Intervention or InterventionPrescription originated.
        /// </summary>
        public string originatingSourceDescriptor { get; set; }

        /// <summary>
        /// (MI EXT) Indicates the academic subset.
        /// </summary>
        public string academicSubsetDescriptor { get; set; }

        /// <summary>
        /// (MI EXT) Indicates the method of the effectiveness measurement.
        /// </summary>
        public string effectivenessMeasurementMethodDescriptor { get; set; }

        /// <summary>
        /// An unordered collection of interventionAcademicSubsets.  (MI EXT) Indicates the academic subset.
        /// </summary>
        public List<InterventionAcademicSubset_Readable> academicSubsets { get; set; }

        /// <summary>
        /// An unordered collection of interventionAppropriateGradeLevels.  Grade levels for the Intervention-if omitted, considered generally applicable.
        /// </summary>
        public List<InterventionAppropriateGradeLevel_Readable> appropriateGradeLevels { get; set; }

        /// <summary>
        /// An unordered collection of interventionAppropriateSexes.  Sexes for the Intervention. If omitted, considered generally applicable.
        /// </summary>
        public List<InterventionAppropriateSex_Readable> appropriateSexes { get; set; }

        /// <summary>
        /// An unordered collection of interventionAvailabilityEducationOrganizations.  Relates the EducationOrganization to the Intervention availability.
        /// </summary>
        public List<InterventionAvailabilityEducationOrganization_Readable> availabilityEducationOrganizations { get; set; }

        /// <summary>
        /// An unordered collection of interventionDeliveryMethods.  The way in which an intervention was implemented: individual, small group, whole class, or whole school.
        /// </summary>
        public List<InterventionDeliveryMethod_Readable> deliveryMethods { get; set; }

        /// <summary>
        /// An unordered collection of interventionDiagnoses.  Targeted purpose of the intervention (e.g., attendance issue, dropout risk).
        /// </summary>
        public List<InterventionDiagnosis_Readable> diagnoses { get; set; }

        /// <summary>
        /// An unordered collection of interventionEducationContents.  Relates the education content source to the education content.
        /// </summary>
        public List<InterventionEducationContent_Readable> educationContents { get; set; }

        /// <summary>
        /// An unordered collection of interventionInterventionPrescriptions.  The reference to the intervention prescription being followed in this intervention implementation.
        /// </summary>
        public List<InterventionInterventionPrescription_Readable> interventionPrescriptions { get; set; }

        /// <summary>
        /// An unordered collection of interventionLearningResourceMetadataURIs.  The URI (typical a URL) pointing to the metadata entry in a LRMI metadata repository, which describes this content item.
        /// </summary>
        public List<InterventionLearningResourceMetadataURI_Readable> learningResourceMetadataURIs { get; set; }

        /// <summary>
        /// An unordered collection of interventionMeetingTimes.  The times at which this intervention is scheduled to meet.
        /// </summary>
        public List<InterventionMeetingTime_Readable> meetingTimes { get; set; }

        /// <summary>
        /// An unordered collection of interventionPopulationServeds.  A subset of students that are the focus of the Intervention.
        /// </summary>
        public List<InterventionPopulationServed_Readable> populationServeds { get; set; }

        /// <summary>
        /// An unordered collection of interventionStaffs.  Relates the staff member associated with the Intervention.
        /// </summary>
        public List<InterventionStaff_Readable> staffs { get; set; }

        /// <summary>
        /// An unordered collection of interventionURIs.  The URI (typical a URL) pointing to an education content item.
        /// </summary>
        public List<InterventionURI_Readable> uris { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

