﻿using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace Michigan.Ods.Sdk.Profiles.SIS.Models 
{
    public class LocalEducationAgency_Readable 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// A reference to the related EducationServiceCenter resource.
        /// </summary>
        public EducationServiceCenterReference educationServiceCenterReference { get; set; }

        /// <summary>
        /// A reference to the related LocalEducationAgency resource.
        /// </summary>
        public LocalEducationAgencyReference parentLocalEducationAgencyReference { get; set; }

        /// <summary>
        /// A reference to the related StateEducationAgency resource.
        /// </summary>
        public StateEducationAgencyReference stateEducationAgencyReference { get; set; }

        /// <summary>
        /// The identifier assigned to a local education agency by the State Education Agency (SEA).
        /// </summary>
        public int? localEducationAgencyId { get; set; }

        /// <summary>
        /// The identifier assigned to an education organization by the StateEducationAgency (SEA).
        /// </summary>
        public string stateOrganizationId { get; set; }

        /// <summary>
        /// The full, legally accepted name of the institution.
        /// </summary>
        public string nameOfInstitution { get; set; }

        /// <summary>
        /// A short name for the institution.
        /// </summary>
        public string shortNameOfInstitution { get; set; }

        /// <summary>
        /// The public web site address (URL) for the EducationOrganization.
        /// </summary>
        public string webSite { get; set; }

        /// <summary>
        /// The current operational status of the EducationOrganization (e.g., active, inactive).
        /// </summary>
        public string operationalStatusType { get; set; }

        /// <summary>
        /// The category of local education agency/district. For example: Independent or Charter.
        /// </summary>
        public string categoryType { get; set; }

        /// <summary>
        /// A school or agency providing free public elementary or secondary education to eligible students under a specific charter granted by the state legislature or other appropriate authority and designated by such authority to be a charter school.
        /// </summary>
        public string charterStatusType { get; set; }

        /// <summary>
        /// (MI EXT) Indicates status (OneRoster orgs.status) of this EdOrg.
        /// </summary>
        public string statusDescriptor { get; set; }

        /// <summary>
        /// An unordered collection of educationOrganizationAddresses.  The set of elements that describes the physical location of the education entity, including the street address, city, state, ZIP code, and ZIP code + 4.
        /// </summary>
        public List<EducationOrganizationAddress_LocalEducationAgency_Readable> addresses { get; set; }

        /// <summary>
        /// An unordered collection of educationOrganizationCategories.  The classification of the education agency within the geographic boundaries of a state according to the level of administrative and operational control granted by the state.
        /// </summary>
        public List<EducationOrganizationCategory_LocalEducationAgency_Readable> educationOrganizationCategories { get; set; }

        /// <summary>
        /// An unordered collection of educationOrganizationIdentificationCodes.  A unique number or alphanumeric code assigned to an education organization by a school, school system, a state, or other agency or entity.
        /// </summary>
        public List<EducationOrganizationIdentificationCode_LocalEducationAgency_Readable> identificationCodes { get; set; }

        /// <summary>
        /// An unordered collection of educationOrganizationInstitutionTelephones.  The 10-digit telephone number, including the area code, for the education entity.
        /// </summary>
        public List<EducationOrganizationInstitutionTelephone_LocalEducationAgency_Readable> institutionTelephones { get; set; }

        /// <summary>
        /// An unordered collection of educationOrganizationInternationalAddresses.  The set of elements that describes the international physical location of the education entity.
        /// </summary>
        public List<EducationOrganizationInternationalAddress_LocalEducationAgency_Readable> internationalAddresses { get; set; }

        /// <summary>
        /// An unordered collection of localEducationAgencyAccountabilities.  This entity maintains information about federal reporting and accountability for Local Education Agencies.
        /// </summary>
        public List<LocalEducationAgencyAccountability_Readable> accountabilities { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

