﻿using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace Michigan.Ods.Sdk.Profiles.SIS.Models 
{
    public class RestraintEvent_Readable 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// A reference to the related School resource.
        /// </summary>
        public SchoolReference schoolReference { get; set; }

        /// <summary>
        /// A reference to the related Student resource.
        /// </summary>
        public StudentReference studentReference { get; set; }

        /// <summary>
        /// A unique number or alphanumeric code assigned to a restraint event by a school, school system, state, or other agency or entity.
        /// </summary>
        public string identifier { get; set; }

        /// <summary>
        /// Month, day, and year of the RestraintEvent.
        /// </summary>
        public DateTime? eventDate { get; set; }

        /// <summary>
        /// The setting where the RestraintEvent was exercised.
        /// </summary>
        public string educationalEnvironmentType { get; set; }

        /// <summary>
        /// An unordered collection of restraintEventPrograms.  The special education program associated with the RestraintEvent.
        /// </summary>
        public List<RestraintEventProgram_Readable> programs { get; set; }

        /// <summary>
        /// An unordered collection of restraintEventReasons.  A categorization of the circumstances or reason for the RestraintEvent.
        /// </summary>
        public List<RestraintEventReason_Readable> reasons { get; set; }

        /// <summary>
        /// An unordered collection of restraintEventRestraintCategories.  (MI EXT) Additional details of seclusion and/or restraint event.
        /// </summary>
        public List<RestraintEventRestraintCategory_Readable> restraintCategories { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

