﻿using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace Michigan.Ods.Sdk.Profiles.SIS.Models 
{
    public class StudentAdultEducationProgramAssociation_Readable 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// A reference to the related EducationOrganization resource.
        /// </summary>
        public EducationOrganizationReference educationOrganizationReference { get; set; }

        /// <summary>
        /// A reference to the related Program resource.
        /// </summary>
        public ProgramReference programReference { get; set; }

        /// <summary>
        /// A reference to the related Student resource.
        /// </summary>
        public StudentReference studentReference { get; set; }

        /// <summary>
        /// The month, day, and year on which the Student first received services.
        /// </summary>
        public DateTime? beginDate { get; set; }

        /// <summary>
        /// The month, day, and year on which the Student exited the Program or stopped receiving services.
        /// </summary>
        public DateTime? endDate { get; set; }

        /// <summary>
        /// The reason the child left the Program within a school or district.
        /// </summary>
        public string reasonExitedDescriptor { get; set; }

        /// <summary>
        /// Indicates whether the student received services during the summer session or between sessions.
        /// </summary>
        public bool? servedOutsideOfRegularSession { get; set; }

        /// <summary>
        /// Added for ELI enrollment status.
        /// </summary>
        public string enrollmentStatus { get; set; }

        /// <summary>
        /// The adult education reporting period during which the student participated in the program.
        /// </summary>
        public string adultEdCountPeriodDescriptor { get; set; }

        /// <summary>
        /// The adult education reporting period year during which the student participated in the program
        /// </summary>
        public int? adultEdCountPeriodYear { get; set; }

        /// <summary>
        /// The full-time equivalency (FTE) that the participant spends in the adult education program reported. 
        /// </summary>
        public double? enrollmentPercent { get; set; }

        /// <summary>
        /// Indicates the exceptions made to allow program participation.
        /// </summary>
        public string eligibilityExceptionDescriptor { get; set; }

        /// <summary>
        /// To indicate the funding source or sources through which the adult education program is provided.
        /// </summary>
        public string adultEdFundingDescriptor { get; set; }

        /// <summary>
        /// An unordered collection of studentProgramAssociationServices.  Indicates the Service(s) being provided to the Student by the Program.
        /// </summary>
        public List<StudentProgramAssociationService_StudentAdultEducationProgramAssociation_Readable> services { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

