﻿using System;
using System.Collections.Generic;
using System.Linq;
using Michigan.Ods.Sdk.Helpers;
using Michigan.Ods.Sdk.Profiles.Transportation.Models;
using RestSharp;
  using System.Net;
  using System.Text;
  
namespace Michigan.Ods.Sdk.Profiles.Transportation.Api 
{
    public class StudentParentAssociationsApi 
    {
        private readonly IRestClient client;

        public StudentParentAssociationsApi(IRestClient client)
        {
            this.client = client;
        }
      
        /// <summary>
        /// Retrieves resources based with paging capabilities (using the &quot;Get All&quot; pattern). This GET operation provides access to resources using the &quot;Get All&quot; pattern. In this version of the API there is support for paging.
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<StudentParentAssociation_Readable>> GetStudentParentAssociationsAll(int? offset= null, int? limit= null) 
        {
            var request = new RestRequest("/studentParentAssociations", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            request.AddHeader("Accept", "application/vnd.ed-fi.studentparentassociation.transportation.readable+json");
            var response = client.Execute<List<StudentParentAssociation_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves resources matching values of an example resource (using the &quot;Get By Example&quot; pattern). This GET operation provides access to resources using the &quot;Get by Example&quot; search pattern.  The values of any properties of the resource that are specified will be used to return all matching results (if it exists).
        /// </summary>
        /// <param name="offset">Indicates how many items should be skipped before returning results.</param>
        /// <param name="limit">Indicates the maximum number of items that should be returned in the results (defaults to 25).</param>
        /// <param name="studentUniqueId">A unique alpha-numeric code assigned to a student.</param>
        /// <param name="parentUniqueId">A unique alpha-numeric code assigned to a parent.</param>
        /// <param name="relationType">The nature of an individual's relationship to a student; for example:          Father, Mother, Step Father, Step Mother, Foster Father, Foster Mother, Guardian, etc.</param>
        /// <param name="primaryContactStatus">Indicator of whether the person is a primary parental contact for the Student.</param>
        /// <param name="livesWith">Indicator of whether the Student lives with the associated parent.</param>
        /// <param name="emergencyContactStatus">Indicator of whether the person is a designated emergency contact for the Student.</param>
        /// <param name="contactPriority">The numeric order of the preferred sequence or priority of contact.</param>
        /// <param name="contactRestrictions">Restrictions for student and/or teacher contact with the individual (e.g., the student may not be picked up by the individual).</param>
        /// <param name="id"></param>
        /// <param name="leaNotification">(MI EXT) Notification to the LEA where the toddler resides must occur at least 90 days prior to the toddler's third birthday for toddlers potentially eligible for Part B preschool services.</param>
        /// <param name="seaNotification">(MI EXT) Notification to the SEA must occur at least 90 days prior to the toddler's third birthday for toddlers potentially eligible for Part B preschool services.</param>
        /// <param name="householdId">(MI EXT) Household identifier for Transportation records.</param>
        /// <param name="primaryPartBReferralContactStatus">(MI EXT) Indicator of whether the person is the primary parental contact for the student for the Part B Referral.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<List<StudentParentAssociation_Readable>> GetStudentParentAssociationsAll(int? offset= null, int? limit= null, string studentUniqueId= null, string parentUniqueId= null, string relationType= null, bool? primaryContactStatus= null, bool? livesWith= null, bool? emergencyContactStatus= null, int? contactPriority= null, string contactRestrictions= null, string id= null, bool? leaNotification= null, bool? seaNotification= null, string householdId= null, bool? primaryPartBReferralContactStatus= null) 
        {
            var request = new RestRequest("/studentParentAssociations", Method.GET);
            request.RequestFormat = DataFormat.Json;

            if (offset != null)
                request.AddParameter("offset", offset);
            if (limit != null)
                request.AddParameter("limit", limit);
            if (studentUniqueId != null)
                request.AddParameter("studentUniqueId", studentUniqueId);
            if (parentUniqueId != null)
                request.AddParameter("parentUniqueId", parentUniqueId);
            if (relationType != null)
                request.AddParameter("relationType", relationType);
            if (primaryContactStatus != null)
                request.AddParameter("primaryContactStatus", primaryContactStatus);
            if (livesWith != null)
                request.AddParameter("livesWith", livesWith);
            if (emergencyContactStatus != null)
                request.AddParameter("emergencyContactStatus", emergencyContactStatus);
            if (contactPriority != null)
                request.AddParameter("contactPriority", contactPriority);
            if (contactRestrictions != null)
                request.AddParameter("contactRestrictions", contactRestrictions);
            if (id != null)
                request.AddParameter("id", id);
            if (leaNotification != null)
                request.AddParameter("leaNotification", leaNotification);
            if (seaNotification != null)
                request.AddParameter("seaNotification", seaNotification);
            if (householdId != null)
                request.AddParameter("householdId", householdId);
            if (primaryPartBReferralContactStatus != null)
                request.AddParameter("primaryPartBReferralContactStatus", primaryPartBReferralContactStatus);
            request.AddHeader("Accept", "application/vnd.ed-fi.studentparentassociation.transportation.readable+json");
            var response = client.Execute<List<StudentParentAssociation_Readable>>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the values of the resource's natural key (using the &quot;Get By Key&quot; pattern). This GET operation provides access to resources using the &quot;Get by Key&quot; search pattern. The values of the natural key of the resource must be fully specified, and the service will return the matching result (if it exists).
        /// </summary>
        /// <param name="studentUniqueId">A unique alpha-numeric code assigned to a student.</param>
        /// <param name="parentUniqueId">A unique alpha-numeric code assigned to a parent.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<StudentParentAssociation_Readable> GetStudentParentAssociationByKey(string studentUniqueId, string parentUniqueId, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/studentParentAssociations", Method.GET);
            request.RequestFormat = DataFormat.Json;

            // verify required params are set
            if (studentUniqueId == null || parentUniqueId == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            if (studentUniqueId != null)
                request.AddParameter("studentUniqueId", studentUniqueId);
            if (parentUniqueId != null)
                request.AddParameter("parentUniqueId", parentUniqueId);
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.studentparentassociation.transportation.readable+json");
            var response = client.Execute<StudentParentAssociation_Readable>(request);

            return response;
        }
        /// <summary>
        /// Retrieves a specific resource using the resource's identifier (using the &quot;Get By Id&quot; pattern). This GET operation retrieves a resource by the specified resource identifier.
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be retrieved.</param>
        /// <param name="IfNoneMatch">The previously returned ETag header value, used here to prevent the unnecessary data transfer of an unchanged resource.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse<StudentParentAssociation_Readable> GetStudentParentAssociationsById(string id, string IfNoneMatch= null) 
        {
            var request = new RestRequest("/studentParentAssociations/{id}", Method.GET);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-None-Match", IfNoneMatch);
            request.AddHeader("Accept", "application/vnd.ed-fi.studentparentassociation.transportation.readable+json");
            var response = client.Execute<StudentParentAssociation_Readable>(request);

            return response;
        }
        /// <summary>
        /// Deletes an existing resource using the resource identifier. The DELETE operation is used to delete an existing resource by identifier.  If the resource doesn't exist, an error will result (the resource will not be found).
        /// </summary>
        /// <param name="id">A resource identifier specifying the resource to be deleted.</param>
        /// <param name="IfMatch">The ETag header value used to prevent the DELETE from removing a resource modified by another consumer.</param>
        /// <returns>A RestSharp <see cref="IRestResponse"/> instance containing the API response details.</returns>
        public IRestResponse DeleteStudentParentAssociationById(string id, string IfMatch= null) 
        {
            var request = new RestRequest("/studentParentAssociations/{id}", Method.DELETE);
            request.RequestFormat = DataFormat.Json;

            request.AddUrlSegment("id", id);
            // verify required params are set
            if (id == null ) 
               throw new ArgumentException("API method call is missing required parameters");
            request.AddHeader("If-Match", IfMatch);
            var response = client.Execute(request);

            return response;
        }
        // patch operation generation was suppressed because profiles can not support patch
    }
}

