﻿using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace Michigan.Ods.Sdk.Profiles.Transportation.Models 
{
    public class School_Readable 
    {
        /// <summary>
        /// The unique identifier of the resource.
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// A reference to the related LocalEducationAgency resource.
        /// </summary>
        public LocalEducationAgencyReference localEducationAgencyReference { get; set; }

        /// <summary>
        /// A reference to the related SchoolYearType resource.
        /// </summary>
        public SchoolYearTypeReference charterApprovalSchoolYearTypeReference { get; set; }

        /// <summary>
        /// The identifier assigned to a school by the State Education Agency (SEA).
        /// </summary>
        public int? schoolId { get; set; }

        /// <summary>
        /// The identifier assigned to an education organization by the StateEducationAgency (SEA).
        /// </summary>
        public string stateOrganizationId { get; set; }

        /// <summary>
        /// The full, legally accepted name of the institution.
        /// </summary>
        public string nameOfInstitution { get; set; }

        /// <summary>
        /// A short name for the institution.
        /// </summary>
        public string shortNameOfInstitution { get; set; }

        /// <summary>
        /// The public web site address (URL) for the EducationOrganization.
        /// </summary>
        public string webSite { get; set; }

        /// <summary>
        /// The current operational status of the EducationOrganization (e.g., active, inactive).
        /// </summary>
        public string operationalStatusType { get; set; }

        /// <summary>
        /// The type of education institution as classified by its primary focus.
        /// </summary>
        public string type { get; set; }

        /// <summary>
        /// A school or agency providing free public elementary or secondary education to eligible students under a specific charter granted by the state legislature or other appropriate authority and designated by such authority to be a charter school.
        /// </summary>
        public string charterStatusType { get; set; }

        /// <summary>
        /// Denotes the Title I Part A designation for the school.
        /// </summary>
        public string titleIPartASchoolDesignationType { get; set; }

        /// <summary>
        /// A school that has been designed: 1) to attract students of different racial/ethnic backgrounds for the purpose of reducing, preventing, or eliminating racial isolation; and/or 2) to provide an academic or social focus on a particular theme (e.g., science/math, performing arts, gifted/talented, or foreign language).
        /// </summary>
        public string magnetSpecialProgramEmphasisSchoolType { get; set; }

        /// <summary>
        /// The type of education institution as classified by its funding source, for example public or private.
        /// </summary>
        public string administrativeFundingControlDescriptor { get; set; }

        /// <summary>
        /// The type of Internet access available.
        /// </summary>
        public string internetAccessType { get; set; }

        /// <summary>
        /// The type of agency that approved the establishment or continuation of a charter school.
        /// </summary>
        public string charterApprovalAgencyType { get; set; }

        /// <summary>
        /// (MI EXT) Indicates status (OneRoster orgs.status) of this EdOrg.
        /// </summary>
        public string statusDescriptor { get; set; }

        /// <summary>
        /// An unordered collection of educationOrganizationAddresses.  The set of elements that describes the physical location of the education entity, including the street address, city, state, ZIP code, and ZIP code + 4.
        /// </summary>
        public List<EducationOrganizationAddress_School_Readable> addresses { get; set; }

        /// <summary>
        /// An unordered collection of educationOrganizationCategories.  The classification of the education agency within the geographic boundaries of a state according to the level of administrative and operational control granted by the state.
        /// </summary>
        public List<EducationOrganizationCategory_School_Readable> educationOrganizationCategories { get; set; }

        /// <summary>
        /// An unordered collection of educationOrganizationIdentificationCodes.  A unique number or alphanumeric code assigned to an education organization by a school, school system, a state, or other agency or entity.
        /// </summary>
        public List<EducationOrganizationIdentificationCode_School_Readable> identificationCodes { get; set; }

        /// <summary>
        /// An unordered collection of educationOrganizationInstitutionTelephones.  The 10-digit telephone number, including the area code, for the education entity.
        /// </summary>
        public List<EducationOrganizationInstitutionTelephone_School_Readable> institutionTelephones { get; set; }

        /// <summary>
        /// An unordered collection of educationOrganizationInternationalAddresses.  The set of elements that describes the international physical location of the education entity.
        /// </summary>
        public List<EducationOrganizationInternationalAddress_School_Readable> internationalAddresses { get; set; }

        /// <summary>
        /// An unordered collection of schoolCategories.  The one or more categories of school. For example: High School, Middle School, and/or Elementary School.
        /// </summary>
        public List<SchoolCategory_Readable> schoolCategories { get; set; }

        /// <summary>
        /// An unordered collection of schoolGradeLevels.  The grade levels served at the school.
        /// </summary>
        public List<SchoolGradeLevel_Readable> gradeLevels { get; set; }

        /// <summary>
        /// A unique system-generated value that identifies the version of the resource.
        /// </summary>
        public string _etag { get; set; }

        }
}

